@@ -3,8 +3,8 @@ class Error:
     Base Error Class
     """
 
-    def __init__(self):
-        self.message = ""
+    def __init__(self) -> None:
+        self.message: str = ""
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return str({"message": self.message})
