@@ -1,3 +1,5 @@
+from typing import Tuple, Optional, Any, Union, Dict
+import requests
 import json
 import logging
 from zscaler.errors.http_error import HTTPError
@@ -7,6 +9,7 @@ from zscaler.exceptions import exceptions
 
 logger = logging.getLogger(__name__)
 
+
 # @staticmethod
 def check_response_for_error(url, response_details, response_body):
     """
