@@ -47,13 +47,14 @@ def to_snake_case(string):
         "dnsResolutionOnTransparentProxyIPv6UrlCategories": "dns_resolution_on_transparent_proxy_ipv6_url_categories",
         "dnsResolutionOnTransparentProxyIPv6Apps": "dns_resolution_on_transparent_proxy_ipv6_apps",
         "enableIPv6DnsOptimizationOnAllTransparentProxy": "enable_ipv6_dns_optimization_on_all_transparent_proxy",
-        "dnsResolutionOnTransparentProxyIPv6ExemptUrlCategories": "dns_resolution_on_transparent_proxy_ipv6_exempt_url_categories",
+        "dnsResolutionOnTransparentProxyIPv6ExemptUrlCategories":
+            "dns_resolution_on_transparent_proxy_ipv6_exempt_url_categories",
         "endPointDLPLogType": "end_point_dlp_log_type",
         "emailDLPLogType": "email_dlp_log_type",
         "extranetDNSList": "extranet_dns_list",
         "primaryDNSServer": "primary_dns_server",
         "secondaryDNSServer": "secondary_dns_server",
-        
+
         # ZCC Edge Case Attributes
         "enableUDPTransportSelection": "enable_udp_transport_selection",
         "interceptZIATrafficAllAdapters": "intercept_zia_traffic_all_adapters",
@@ -118,7 +119,7 @@ def to_snake_case(string):
         "enableZCCRevert": "enable_zcc_revert",
         "enableZiaDR": "enable_zia_dr",
         "purgeKerberosPreferredDCCache": "purge_kerberos_preferred_dc_cache",
-        
+
         # ZPA Edge Cases
         "serverGroupDTOs": "server_group_dtos",
         "extranetDTO": "extranet_dto",
@@ -126,7 +127,8 @@ def to_snake_case(string):
         "locationDTO": "location_dto",
         "predefinedADPControls": "predefined_adp_controls",
         "runtimeOS": "runtime_os",
-        
+        "defaultCSP": "default_csp",
+
         # ZIdentity Edge Cases
         # "clientJWKsUrl": "clientJWKsUrl",
     }
@@ -152,6 +154,7 @@ def to_lower_camel_case(string):
     FIELD_EXCEPTIONS = {
         "predefined_adp_controls": "predefinedADPControls",
         "surrogate_ip": "surrogateIP",
+        "surrogate_ip_enforced_for_known_browsers": "surrogateIPEnforcedForKnownBrowsers",
         "internal_ip_range": "internalIpRange",
         "start_ip_address": "startIPAddress",
         "end_ip_address": "endIPAddress",
@@ -183,14 +186,16 @@ def to_lower_camel_case(string):
         "dns_resolution_on_transparent_proxy_ipv6_exempt_apps": "dnsResolutionOnTransparentProxyIPv6ExemptApps",
         "dns_resolution_on_transparent_proxy_ipv6_url_categories": "dnsResolutionOnTransparentProxyIPv6UrlCategories",
         "dns_resolution_on_transparent_proxy_ipv6_apps": "dnsResolutionOnTransparentProxyIPv6Apps",
-        "enable_ipv6_dns_optimization_on_all_transparent_proxy": "enableIPv6DnsOptimizationOnAllTransparentProxy",
-        "dns_resolution_on_transparent_proxy_ipv6_exempt_url_categories": "dnsResolutionOnTransparentProxyIPv6ExemptUrlCategories",
+        "enable_ipv6_dns_optimization_on_all_transparent_proxy":
+            "enableIPv6DnsOptimizationOnAllTransparentProxy",
+        "dns_resolution_on_transparent_proxy_ipv6_exempt_url_categories":
+            "dnsResolutionOnTransparentProxyIPv6ExemptUrlCategories",
         "end_point_dlp_log_type": "endPointDLPLogType",
         "email_dlp_log_type": "emailDLPLogType",
         "extranet_dns_list": "extranetDNSList",
         "primary_dns_server": "primaryDNSServer",
         "secondary_dns_server": "secondaryDNSServer",
-        
+
         # ZCC Edge Case Attributes
         "enable_udp_transport_selection": "enableUDPTransportSelection",
         "intercept_zia_traffic_all_adapters": "interceptZIATrafficAllAdapters",
@@ -254,14 +259,15 @@ def to_lower_camel_case(string):
         "delete_dhcp_option121_routes": "deleteDHCPOption121Routes",
         "enableZiaDR": "enable_zia_dr",
         "purgeKerberosPreferredDCCache": "purge_kerberos_preferred_dc_cache",
-        
+
         # ZPA Edge Cases
         "server_group_dtos": "serverGroupDTOs",
         "extranet_dto": "extranetDTO",
         "location_group_dto": "locationGroupDTO",
         "location_dto": "locationDTO",
         "predefined_adp_controls": "predefinedADPControls",
-        "runtime_os": "runtimeOS"
+        "runtime_os": "runtimeOS",
+        "default_csp": "defaultCSP",
     }
 
     if string in FIELD_EXCEPTIONS:
@@ -313,3 +319,36 @@ def convert_keys_to_camel_case(data):
         return [convert_keys_to_camel_case(item) for item in data]
     else:
         return data
+
+
+def convert_keys_to_camel_case_selective(data, preserve_snake_case_keys=None):
+    """
+    Recursively convert keys to camelCase while preserving specific snake_case keys.
+    This function allows users to use snake_case for all attributes, and only converts
+    to camelCase if the attribute is NOT in the preserve_snake_case_keys set.
+
+    Args:
+        data: Dictionary or list to convert
+        preserve_snake_case_keys: Set of keys that should remain in snake_case
+
+    Returns:
+        Converted data with selective key preservation
+    """
+    if preserve_snake_case_keys is None:
+        preserve_snake_case_keys = set()
+
+    if isinstance(data, dict):
+        result = {}
+        for k, v in data.items():
+            # Check if this key should be preserved in snake_case
+            if k in preserve_snake_case_keys:
+                # Keep as snake_case
+                result[k] = convert_keys_to_camel_case_selective(v, preserve_snake_case_keys)
+            else:
+                # Convert to camelCase
+                result[to_lower_camel_case(k)] = convert_keys_to_camel_case_selective(v, preserve_snake_case_keys)
+        return result
+    elif isinstance(data, list):
+        return [convert_keys_to_camel_case_selective(item, preserve_snake_case_keys) for item in data]
+    else:
+        return data
