@@ -1,3 +1,4 @@
+from typing import Dict, Any, Optional, TypeVar
 import requests
 import logging
 import os
@@ -23,21 +24,23 @@ from zscaler.zpa.legacy import LegacyZPAClientHelper
 from zscaler.zia.legacy import LegacyZIAClientHelper
 from zscaler.zwa.legacy import LegacyZWAClientHelper
 
+TLegacy = TypeVar("TLegacy")
+
 
 class Client:
     """A Zscaler client object"""
 
     def __init__(
         self,
-        user_config: dict = {},
-        zcc_legacy_client: LegacyZCCClientHelper = None,
-        ztw_legacy_client: LegacyZTWClientHelper = None,
-        zdx_legacy_client: LegacyZDXClientHelper = None,
-        zpa_legacy_client: LegacyZPAClientHelper = None,
-        zia_legacy_client: LegacyZIAClientHelper = None,
-        zwa_legacy_client: LegacyZWAClientHelper = None,
+        user_config: Dict[str, Any] = {},
+        zcc_legacy_client: Optional[LegacyZCCClientHelper] = None,
+        ztw_legacy_client: Optional[LegacyZTWClientHelper] = None,
+        zdx_legacy_client: Optional[LegacyZDXClientHelper] = None,
+        zpa_legacy_client: Optional[LegacyZPAClientHelper] = None,
+        zia_legacy_client: Optional[LegacyZIAClientHelper] = None,
+        zwa_legacy_client: Optional[LegacyZWAClientHelper] = None,
         use_legacy_client: bool = False,
-    ):
+    ) -> None:
         self.use_legacy_client = use_legacy_client
         self.zcc_legacy_client = zcc_legacy_client
         self.ztw_legacy_client = ztw_legacy_client
@@ -207,7 +210,7 @@ class Client:
     @property
     def zcc(self):
         if self.use_legacy_client:
-            return self.zcc_legacy_client
+            return self._require_legacy_client("ZCC", self.zcc_legacy_client)
         if self._zcc is None:
             self._zcc = ZCCService(self)
         return self._zcc
@@ -215,7 +218,7 @@ class Client:
     @property
     def zdx(self):
         if self.use_legacy_client:
-            return self.zdx_legacy_client
+            return self._require_legacy_client("ZDX", self.zdx_legacy_client)
         if self._zdx is None:
             self._zdx = ZDXService(self)
         return self._zdx
@@ -223,7 +226,7 @@ class Client:
     @property
     def zia(self):
         if self.use_legacy_client:
-            return self.zia_legacy_client
+            return self._require_legacy_client("ZIA", self.zia_legacy_client)
         if self._zia is None:
             # Pass RequestExecutor directly
             self._zia = ZIAService(self._request_executor)
@@ -232,7 +235,7 @@ class Client:
     @property
     def zwa(self):
         if self.use_legacy_client:
-            return self.zwa_legacy_client
+            return self._require_legacy_client("ZWA", self.zwa_legacy_client)
         if self._zwa is None:
             self._zwa = ZWAService(self)
         return self._zwa
@@ -240,7 +243,7 @@ class Client:
     @property
     def ztw(self):
         if self.use_legacy_client:
-            return self.ztw_legacy_client
+            return self._require_legacy_client("ZTW", self.ztw_legacy_client)
         if self._ztw is None:
             # Pass RequestExecutor directly
             self._ztw = ZTWService(self._request_executor)
@@ -249,7 +252,7 @@ class Client:
     @property
     def zpa(self):
         if self.use_legacy_client:
-            return self.zpa_legacy_client
+            return self._require_legacy_client("ZPA", self.zpa_legacy_client)
         if self._zpa is None:
             self._zpa = ZPAService(self._request_executor, self._config)
         return self._zpa
@@ -259,7 +262,7 @@ class Client:
         if self._zidentity is None:
             self._zidentity = ZIdentityService(self._request_executor)
         return self._zidentity
-    
+
     def __enter__(self):
         """
         Automatically create and set session within context manager.
@@ -276,7 +279,7 @@ class Client:
         if hasattr(self, "_session"):
             self._session.close()
             self.logger.debug("Session closed.")
-        
+
         # Clean up Zscaler authentication session
         if hasattr(self, '_request_executor'):
             # For legacy clients, use their deauthenticate method
@@ -291,8 +294,9 @@ class Client:
                 service_type = getattr(self._request_executor, '_last_service_type', None)
                 if not service_type:
                     service_type = self._config.get("client", {}).get("service", "zia")
-                
+
                 if service_type.lower() in ["zia", "ztw"]:
+                    # For ZIA, deauthenticate only if mutations occurred; executor will decide.
                     self.logger.debug(f"Deauthenticating Zscaler session for {service_type} service.")
                     self._request_executor.deauthenticate(service_type)
                     self.logger.debug(f"Zscaler session deauthenticated for {service_type}.")
@@ -317,6 +321,21 @@ class Client:
     def clear_custom_headers(self):
         self._request_executor.clear_custom_headers()
 
+    def _require_legacy_client(self, service_name: str, client: Optional[TLegacy]) -> TLegacy:
+        """
+        Ensure a legacy client instance is available before returning it.
+
+        Raises:
+            RuntimeError: If the legacy client was requested but not provided.
+        """
+        if client is None:
+            raise RuntimeError(
+                f"Legacy {service_name} client requested but no legacy client instance was provided. "
+                "Pass the appropriate legacy helper when constructing the Client or disable "
+                "use_legacy_client."
+            )
+        return client
+
     def get_custom_headers(self):
         return self._request_executor.get_custom_headers()
 
@@ -334,6 +353,7 @@ class LegacyZPAClient(Client):
         customer_id = config.get("customerId", os.getenv("ZPA_CUSTOMER_ID"))
         cloud = config.get("cloud", os.getenv("ZSCALER_CLOUD", "PRODUCTION"))
         microtenant_id = config.get("microtenantId", os.getenv("ZPA_MICROTENANT_ID"))
+        partner_id = config.get("partnerId", os.getenv("ZSCALER_PARTNER_ID"))
         timeout = config.get("timeout", 240)
         cache = config.get("cache", None)
         fail_safe = config.get("failSafe", None)
@@ -346,6 +366,7 @@ class LegacyZPAClient(Client):
             customer_id=customer_id,
             cloud=cloud,
             microtenant_id=microtenant_id,
+            partner_id=partner_id,
             timeout=timeout,
             cache=cache,
             fail_safe=fail_safe,
@@ -363,10 +384,13 @@ class LegacyZIAClient(Client):
         password = config.get("password", os.getenv("ZIA_PASSWORD"))
         api_key = config.get("api_key", os.getenv("ZIA_API_KEY"))
         cloud = config.get("cloud", os.getenv("ZIA_CLOUD"))
+        partner_id = config.get("partnerId", os.getenv("ZSCALER_PARTNER_ID"))
         timeout = config.get("timeout", 240)
         cache = config.get("cache", None)
         fail_safe = config.get("failSafe", None)
         request_executor_impl = config.get("requestExecutor", None)
+        session_safety_margin = config.get("session_safety_margin", None)
+        use_session_validation = config.get("use_session_validation", None)
 
         # Initialize the LegacyZIAClientHelper with the extracted parameters
         legacy_helper = LegacyZIAClientHelper(
@@ -374,10 +398,13 @@ class LegacyZIAClient(Client):
             password=password,
             api_key=api_key,
             cloud=cloud,
+            partner_id=partner_id,
             timeout=timeout,
             cache=cache,
             fail_safe=fail_safe,
             request_executor_impl=request_executor_impl,
+            session_safety_margin=session_safety_margin,
+            use_session_validation=use_session_validation,
         )
         super().__init__(config, zia_legacy_client=legacy_helper, use_legacy_client=True)
 
@@ -391,6 +418,7 @@ class LegacyZTWClient(Client):
         password = config.get("password", os.getenv("ZTW_PASSWORD"))
         api_key = config.get("api_key", os.getenv("ZTW_API_KEY"))
         cloud = config.get("cloud", os.getenv("ZTW_CLOUD"))
+        partner_id = config.get("partnerId", os.getenv("ZSCALER_PARTNER_ID"))
         timeout = config.get("timeout", 240)
         cache = config.get("cache", None)
         fail_safe = config.get("failSafe", None)
@@ -401,6 +429,7 @@ class LegacyZTWClient(Client):
             password=password,
             api_key=api_key,
             cloud=cloud,
+            partner_id=partner_id,
             timeout=timeout,
             cache=cache,
             fail_safe=fail_safe,
@@ -417,6 +446,7 @@ class LegacyZCCClient(Client):
         api_key = config.get("api_key", os.getenv("ZCC_CLIENT_ID"))
         secret_key = config.get("secret_key", os.getenv("ZCC_CLIENT_SECRET"))
         cloud = config.get("cloud", os.getenv("ZCC_CLOUD"))
+        partner_id = config.get("partnerId", os.getenv("ZSCALER_PARTNER_ID"))
         timeout = config.get("timeout", 240)
         request_executor_impl = config.get("requestExecutor", None)
 
@@ -425,6 +455,7 @@ class LegacyZCCClient(Client):
             api_key=api_key,
             secret_key=secret_key,
             cloud=cloud,
+            partner_id=partner_id,
             timeout=timeout,
             request_executor_impl=request_executor_impl,
         )
@@ -439,6 +470,7 @@ class LegacyZDXClient(Client):
         client_id = config.get("key_id", os.getenv("ZDX_CLIENT_ID"))
         client_secret = config.get("key_secret", os.getenv("ZDX_CLIENT_SECRET"))
         cloud = config.get("cloud", os.getenv("ZDX_CLOUD", "zdxcloud"))
+        partner_id = config.get("partnerId", os.getenv("ZSCALER_PARTNER_ID"))
         timeout = config.get("timeout", 240)
         request_executor_impl = config.get("requestExecutor", None)
         # Initialize the LegacyZDXClientHelper with the extracted parameters
@@ -446,6 +478,7 @@ class LegacyZDXClient(Client):
             client_id=client_id,
             client_secret=client_secret,
             cloud=cloud,
+            partner_id=partner_id,
             timeout=timeout,
             request_executor_impl=request_executor_impl,
         )
@@ -460,6 +493,7 @@ class LegacyZWAClient(Client):
         key_id = config.get("key_id", os.getenv("ZWA_CLIENT_ID"))
         key_secret = config.get("key_secret", os.getenv("ZWA_CLIENT_SECRET"))
         cloud = config.get("cloud", os.getenv("ZWA_CLOUD", "us1"))
+        partner_id = config.get("partnerId", os.getenv("ZSCALER_PARTNER_ID"))
         timeout = config.get("timeout", 240)
         request_executor_impl = config.get("requestExecutor", None)
         # Initialize the LegacyZWAClientHelper with the extracted parameters
@@ -467,6 +501,7 @@ class LegacyZWAClient(Client):
             key_id=key_id,
             key_secret=key_secret,
             cloud=cloud,
+            partner_id=partner_id,
             timeout=timeout,
             request_executor_impl=request_executor_impl,
         )
