@@ -1,8 +1,13 @@
+from typing import List, Type, TypeVar, Any
+
+T = TypeVar('T')
+
+
 class ZscalerCollection:
     "Class to build lists composed of ZscalerObject datatypes"
 
     @staticmethod
-    def form_list(collection: list, data_type: type):
+    def form_list(collection: List[Any], data_type: Type[T]) -> List[T]:
         if not collection:
             # If empty list or None
             return []
@@ -12,5 +17,5 @@ class ZscalerCollection:
         return collection
 
     @staticmethod
-    def is_formed(value, data_type: type):
+    def is_formed(value: Any, data_type: Type[T]) -> bool:
         return isinstance(value, data_type)
