@@ -1,6 +1,9 @@
+from typing import Dict, Any, Optional, Tuple, List, Union
 import logging
 import time
 import uuid
+import re
+from urllib.parse import quote
 from zscaler.oneapi_http_client import HTTPClient
 from zscaler.oneapi_response import ZscalerAPIResponse
 from zscaler.oneapi_oauth_client import OAuth
@@ -84,10 +87,15 @@ class RequestExecutor:
         self.customer_id = self._config["client"].get("customerId")  # Optional for ZIA/ZCC
         self.microtenant_id = self._config["client"].get("microtenantId")  # Optional for ZIA/ZCC
         self.vanity_domain = self._config["client"].get("vanityDomain")  # Required for zidentity service
+        self.partner_id = self._config["client"].get("partnerId")  # Optional partner ID
 
-        # OAuth2 setup
-        self._oauth = OAuth(self, self._config)
-        self._access_token = None
+        # OAuth2 setup - only for OneAPI clients, not legacy clients
+        if not self.use_legacy_client:
+            self._oauth = OAuth(self, self._config)
+            self._access_token = None
+        else:
+            self._oauth = None
+            self._access_token = None
 
         # Set default headers from config
         self._default_headers = {
@@ -96,6 +104,10 @@ class RequestExecutor:
             "Content-Type": "application/json",
         }
 
+        # Add x-partner-id header if partnerId is provided in config
+        if self.partner_id:
+            self._default_headers["x-partner-id"] = self.partner_id
+
         # Initialize the HTTP client, considering proxy and SSL context from config
         http_client_impl = http_client or HTTPClient
         self._http_client = http_client_impl(
@@ -116,6 +128,10 @@ class RequestExecutor:
         exceptions.raise_exception = self._config["client"].get("raiseException", False)
         self._custom_headers = {}
 
+        # Track whether any mutations (POST/PUT/DELETE) have occurred during this session
+        # This is used to determine if deauthentication is needed for ZIA/ZTW services
+        self._mutations_occurred = False
+
     def get_base_url(self, endpoint: str) -> str:
         """
         Gets the appropriate base URL based on the cloud value.
@@ -128,18 +144,18 @@ class RequestExecutor:
         # logger.debug(f"Determining base URL for cloud: {self.cloud}")
         if "/zscsb" in endpoint:
             return f"https://csbapi.{self.sandbox_cloud}.net"
-        
+
         # Special handling for zidentity service
         if "/zidentity" in endpoint or "/admin/api/v1" in endpoint:
             if not self.vanity_domain:
                 raise ValueError("vanityDomain is required for zidentity service")
-            
+
             # For zidentity, the URL pattern is: https://{{vanity_domain}}-admin.zslogin{{cloud}}.net/admin/api/v1
             if self.cloud and self.cloud != "production":
                 return f"https://{self.vanity_domain}-admin.zslogin{self.cloud}.net/admin/api/v1"
             else:
                 return f"https://{self.vanity_domain}-admin.zslogin.net/admin/api/v1"
-        
+
         if self.cloud and self.cloud != "production":
             return f"https://api.{self.cloud}.zsapi.net"
         return self.BASE_URL
@@ -252,7 +268,7 @@ class RequestExecutor:
 
         # Track the service type for deauthentication
         self._last_service_type = service_type
-        
+
         request = {
             "method": method,
             "url": final_url,
@@ -261,7 +277,12 @@ class RequestExecutor:
             "uuid": uuid.uuid4(),
             "service_type": service_type,
         }
-        if use_raw_data_for_body:
+
+        # Special handling for PAC file validation endpoint
+        if "/pacFiles/validate" in endpoint and service_type == "zia":
+            # For PAC file validation, send as raw data without any modification
+            request["data"] = body
+        elif use_raw_data_for_body:
             request["data"] = body
         else:
             json_payload = self._prepare_body(endpoint, body)
@@ -269,7 +290,14 @@ class RequestExecutor:
         return request, None
 
     def _prepare_headers(self, headers, endpoint=""):
-        headers = {**self._default_headers, **(self._custom_headers or {}), **headers}
+        # Special handling for PAC file validation - preserve custom Content-Type
+        if "/pacFiles/validate" in endpoint:
+            # For PAC validation, don't override Content-Type from default headers
+            default_headers = {k: v for k, v in self._default_headers.items() if k != "Content-Type"}
+            headers = {**default_headers, **(self._custom_headers or {}), **headers}
+        else:
+            headers = {**self._default_headers, **(self._custom_headers or {}), **headers}
+
         if "/zscsb" not in endpoint and not self.use_legacy_client:
             headers["Authorization"] = f"Bearer {self._oauth._get_access_token()}"
         return headers
@@ -286,6 +314,14 @@ class RequestExecutor:
         if "/zdx/" in endpoint:
             return body  # Do not convert ZDX requests to camelCase
 
+        # Special handling for ZCC service - use selective conversion
+        if "/zcc/" in endpoint and body:
+            from zscaler.helpers import convert_keys_to_camel_case_selective
+            from zscaler.zcc.models.webpolicy import WebPolicy
+            # Use the WebPolicy's snake_case keys for selective conversion
+            body = convert_keys_to_camel_case_selective(body, WebPolicy.SNAKE_CASE_KEYS)
+            return body
+
         # Preserve existing logic for other services
         if body:
             body = convert_keys_to_camel_case(body)
@@ -327,6 +363,38 @@ class RequestExecutor:
 
                 params = converted
 
+            # Handle search parameter for ZPA - the API now uses a filtering/query parameter format.
+            # The search string must be in the format: fieldName operator fieldValue
+            # Examples: "name+EQ+CDE Segment Group", "enabled+EQ+true"
+            # 
+            # For user convenience, if a simple string is provided (not in filter format),
+            # we automatically convert it to "name+EQ+<search_string>" for exact name matching.
+            # If the search string already contains operators (EQ, NE, GT, LT, etc.), we use it as-is.
+            if "search" in params and isinstance(params["search"], str):
+                search_value = params["search"].strip()
+                if search_value:
+                    # Remove any existing quotes
+                    if search_value.startswith('"') and search_value.endswith('"'):
+                        search_value = search_value[1:-1]
+                    
+                    # Check if the search string already contains filter operators
+                    # Common ZPA filter operators: EQ, NE, GT, LT, GE, LE, CONTAINS, STARTSWITH, ENDSWITH
+                    filter_operators = ['+EQ+', '+NE+', '+GT+', '+LT+', '+GE+', '+LE+', 
+                                      '+CONTAINS+', '+STARTSWITH+', '+ENDSWITH+',
+                                      '%2BEQ%2B', '%2BNE%2B', '%2BGT%2B', '%2BLT%2B', 
+                                      '%2BGE%2B', '%2BLE%2B']
+                    
+                    # Check if search value already contains any filter operator pattern
+                    has_filter_operator = any(op in search_value.upper() for op in filter_operators)
+                    
+                    if not has_filter_operator:
+                        # Simple search string - convert to name+EQ+<search_string> format
+                        # This provides exact name matching by default
+                        params["search"] = f"name+EQ+{search_value}"
+                    else:
+                        # Already in filter format - use as-is
+                        params["search"] = search_value
+
             # Finally, handle microtenant (unchanged)
             microtenant_id = self._get_microtenant_id(body, params)
             if microtenant_id:
@@ -346,7 +414,12 @@ class RequestExecutor:
             return params["microtenantId"]
         return self.microtenant_id
 
-    def execute(self, request, response_type=None, return_raw_response=False):
+    def execute(
+        self,
+        request: Dict[str, Any],
+        response_type: Optional[type] = None,
+        return_raw_response: bool = False,
+    ) -> Tuple[Optional["ZscalerAPIResponse"], Optional[Exception]]:
         """
         High-level request execution method.
         Args:
@@ -434,7 +507,7 @@ class RequestExecutor:
     def _cache_enabled(self):
         return self._config["client"]["cache"]["enabled"] == True
 
-    def fire_request(self, request):
+    def fire_request(self, request: Dict[str, Any]) -> Tuple[Optional["ZscalerAPIResponse"], Optional[int], Optional[str], Optional[Exception]]:
         """
         Send request using HTTP client.
 
@@ -497,6 +570,14 @@ class RequestExecutor:
             logger.warning("Request Timeout exceeded.")
             return None, None, None, Exception("Request Timeout exceeded.")
 
+        # Track mutations (POST/PUT/DELETE) for ZIA/ZTW deauthentication logic
+        if request["method"].upper() in ["POST", "PUT", "DELETE"]:
+            self._mutations_occurred = True
+            logger.debug(f"Mutation detected: {request['method']} request to {request['url']}")
+        else:
+            logger.debug(f"Non-mutation request: {request['method']} request to {request['url']} "
+                         f"(mutations_occurred={self._mutations_occurred})")
+
         # Perform the actual HTTP request
         response, error = self._http_client.send_request(request)
 
@@ -507,7 +588,7 @@ class RequestExecutor:
         # Check for 401 -> Trigger re-auth if we still have retries left
         if response.status_code == 401:
             # We only want to attempt refreshing the token if we haven't hit max_retries
-            if attempts < max_retries:
+            if attempts < max_retries and self._oauth is not None:
                 logger.info("Got 401 response; clearing token and re-authenticating.")
                 self._oauth.clear_access_token()
 
@@ -523,8 +604,9 @@ class RequestExecutor:
                 attempts += 1
                 return self.fire_request_helper(request, attempts, request_start_time)
             else:
-                logger.error("401 Unauthorized - token refresh attempts exhausted.")
-                return request, response, response.text, Exception("401 Unauthorized - token refresh attempts exhausted.")
+                logger.error("401 Unauthorized - token refresh attempts exhausted or OAuth not available.")
+                return request, response, response.text, Exception(
+                    "401 Unauthorized - token refresh attempts exhausted or OAuth not available.")
 
         # Handle “retryable” statuses such as 429, 503, etc.
         if attempts < max_retries and self.is_retryable_status(response.status_code):
@@ -545,11 +627,11 @@ class RequestExecutor:
         """
         Checks if HTTP status is retryable.
 
-        Retryable statuses: 408, 409, 412, 429, 500, 502, 503, 504
+        Retryable statuses: 429, 500, 502, 503, 504
         """
         return status is not None and status in (
-            HTTPStatus.REQUEST_TIMEOUT,
-            HTTPStatus.CONFLICT,
+            # HTTPStatus.REQUEST_TIMEOUT,
+            # HTTPStatus.CONFLICT,
             # HTTPStatus.PRECONDITION_FAILED,
             HTTPStatus.TOO_MANY_REQUESTS,
             HTTPStatus.SERVICE_UNAVAILABLE,
@@ -616,53 +698,73 @@ class RequestExecutor:
         logger.debug("Getting custom headers.")
         return self._custom_headers
 
+    def get_default_headers(self):
+        """
+        Get the current default headers (includes x-partner-id if partnerId is in config).
+        """
+        logger.debug("Getting default headers.")
+        return self._default_headers.copy()
+
+    def has_mutations_occurred(self):
+        """
+        Check if any mutations (POST/PUT/DELETE) have occurred during this session.
+
+        Returns:
+            bool: True if mutations occurred, False otherwise.
+        """
+        return self._mutations_occurred
+
     def deauthenticate(self, service_type=None):
         """
         Deauthenticate from Zscaler services that support session-based authentication.
         Currently supports ZIA and ZTW services.
-        
+
+        For both ZIA and ZTW services, deauthentication is only performed if mutations
+        (POST/PUT/DELETE) have occurred during the session. GET-only sessions do not
+        require deauthentication.
+
         Args:
             service_type (str, optional): The service type to deauthenticate from.
                 If None, will attempt to determine from the current configuration.
         """
         if not service_type:
             service_type = self.service
-        
+
         if service_type.lower() not in ["zia", "ztw"]:
             logger.debug(f"Deauthentication not supported for service: {service_type}")
             return False
-        
+
+        # For both ZIA and ZTW services, only deauthenticate if mutations occurred
+        if service_type.lower() in ["zia", "ztw"] and not self._mutations_occurred:
+            logger.debug(f"{service_type.upper()} service: No mutations occurred during session, skipping deauthentication")
+            return True
+
         try:
             # Determine the base URL and endpoint based on service type
             if service_type.lower() == "zia":
-                if self.cloud and self.cloud != "production":
-                    base_url = f"https://api.{self.cloud}.zsapi.net"
-                else:
-                    base_url = "https://api.{self.cloud}.zsapi.net"
+                base_url = self.get_base_url("/zia/api/v1/authenticatedSession")
                 endpoint = "/zia/api/v1/authenticatedSession"
             elif service_type.lower() == "ztw":
-                if self.cloud and self.cloud != "production":
-                    base_url = f"https://api.{self.cloud}.zsapi.net"
-                else:
-                    base_url = "https://api.{self.cloud}.zsapi.net"
+                base_url = self.get_base_url("/ztw/api/v1/auth")
                 endpoint = "/ztw/api/v1/auth"
-            
+
             url = f"{base_url}{endpoint}"
-            
+
             # Prepare headers using the standard method to include bearer token
             # For DELETE requests, we'll exclude Content-Type to avoid issues with empty body
             headers = self._prepare_headers({}, endpoint)
             # Remove Content-Type for DELETE requests to avoid issues with empty body
             headers.pop("Content-Type", None)
-            
+
             # Both ZIA and ZTW require explicit deauthentication to activate staged configurations
-            # regardless of authentication method (OAuth or session-based)
+            # but only when mutations (POST/PUT/DELETE) have occurred during the session
             if service_type.lower() in ["zia", "ztw"]:
-                logger.debug(f"{service_type.upper()} service requires explicit deauthentication to activate staged configurations")
-            
+                logger.debug(f"{service_type.upper()} service requires explicit deauthentication to activate "
+                             f"staged configurations")
+
             # Send DELETE request to deauthenticate
             logger.debug(f"Deauthenticating from {service_type} at {url}")
-            
+
             # Use the HTTP client to send the request
             request = {
                 "method": "DELETE",
@@ -672,31 +774,30 @@ class RequestExecutor:
                 "uuid": uuid.uuid4(),
                 "service_type": service_type,
             }
-            
+
             response, error = self._http_client.send_request(request)
-            
+
             if error:
                 logger.warning(f"Failed to deauthenticate from {service_type}: {error}")
                 return False
-            
+
             if response and response.status_code == 200:
                 logger.debug(f"Successfully deauthenticated from {service_type}")
                 return True
             else:
                 logger.warning(f"Unexpected response during deauthentication: {response.status_code if response else 'No response'}")
                 return False
-                
+
         except Exception as e:
             logger.warning(f"Exception during deauthentication for {service_type}: {e}")
             return False
 
-
     def get_retry_after(self, headers, logger):
         retry_limit_reset_header = (
-            headers.get("x-ratelimit-reset") or 
+            headers.get("x-ratelimit-reset") or
             headers.get("X-RateLimit-Reset") or
             headers.get("RateLimit-Reset") or
-            
+
             # ZCC Specific Rate Limiting Headers (LegacyZCCClientHelper)
             headers.get("X-Rate-Limit-Retry-After-Seconds") or
             headers.get("X-Rate-Limit-Remaining")
