@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.utils import format_url, zcc_param_map, zcc_param_mapper
@@ -23,12 +24,13 @@ from zscaler.zcc.models.devices import ForceRemoveDevices
 from zscaler.zcc.models.devices import SetDeviceCleanupInfo
 from zscaler.zcc.models.devices import DeviceCleanup
 from zscaler.zcc.models.devices import DeviceDetails
+from zscaler.types import APIResult
 from datetime import datetime
 
 
 class DevicesAPI(APIClient):
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
         self._zcc_base_endpoint = "/zcc/papi/public/v1"
@@ -210,7 +212,105 @@ class DevicesAPI(APIClient):
         return filename
 
     @zcc_param_mapper
-    def list_devices(self, query_params=None) -> tuple:
+    def download_disable_reasons(self, query_params=None, filename: str = None):
+        """
+        Downloads or exports a report as a CSV file showing the disable reasons of devices.
+
+        Args:
+            query_params (dict, optional): A dictionary containing supported filters.
+
+                ``[query_params.os_types]`` {list}: Filter by OS type. Valid values:
+                    ios, android, windows, macos, linux.
+
+                ``[query_params.start_date]`` {str}: Start date for the report. Accepts various formats:
+                    YYYY-MM-DD, YYYY-MM-DD HH:MM:SS, YYYY-MM-DDTHH:MM:SS, etc. Will be converted to ZCC API format.
+
+                ``[query_params.end_date]`` {str}: End date for the report. Accepts various formats:
+                    YYYY-MM-DD, YYYY-MM-DD HH:MM:SS, YYYY-MM-DDTHH:MM:SS, etc. Will be converted to ZCC API format.
+
+                ``[query_params.time_zone]`` {str}: IANA time zone for date interpretation.
+                    Examples: 'America/New_York', 'UTC', 'Europe/London'.
+
+            filename (str, optional): Custom filename for the CSV file. Defaults to timestamped name.
+
+        Returns:
+            str: Path to the downloaded CSV file.
+
+        Examples:
+            Download disable reasons report for Windows devices:
+
+            >>> try:
+            ...     filename = client.zcc.devices.download_disable_reasons(
+            ...         query_params={
+            ...             "os_types": ["windows"],
+            ...             "start_date": "2024-01-01",
+            ...             "end_date": "2024-01-31",
+            ...             "time_zone": "America/New_York"
+            ...         },
+            ...         filename="disable_reasons_jan2024.csv"
+            ...     )
+            ...     print(f"Disable reasons report downloaded successfully: {filename}")
+            ... except Exception as e:
+            ...     print(f"Error during download: {e}")
+
+            Download disable reasons for all devices with specific date range:
+
+            >>> try:
+            ...     filename = client.zcc.devices.download_disable_reasons(
+            ...         query_params={
+            ...             "start_date": "2024-01-01 00:00:00",
+            ...             "end_date": "2024-01-31 23:59:59",
+            ...             "time_zone": "UTC"
+            ...         }
+            ...     )
+            ...     print(f"Report downloaded: {filename}")
+            ... except Exception as e:
+            ...     print(f"Error: {e}")
+        """
+        query_params = query_params or {}
+
+        if not filename:
+            filename = f"zcc-disable-reasons-{datetime.now().strftime('%Y%m%d-%H_%M_%S')}.csv"
+
+        # The zcc_param_mapper decorator handles parameter mapping and validation
+        # We just need to pass the query_params through
+        params = query_params.copy()
+
+        http_method = "get".upper()
+        api_url = format_url(f"{self._zcc_base_endpoint}/downloadDisableReasons")
+
+        # Prepare headers - include Time-Zone if provided
+        headers = {"Accept": "*/*"}
+        if "Time-Zone" in params:
+            headers["Time-Zone"] = params.pop("Time-Zone")
+
+        request, error = self._request_executor.create_request(
+            http_method,
+            api_url,
+            params=params,
+            headers=headers
+        )
+
+        if error:
+            raise Exception("Error creating request for downloading disable reasons report.")
+
+        response, error = self._request_executor.execute(request, return_raw_response=True)
+        if error:
+            raise error
+        if response is None:
+            raise Exception("No response received when downloading disable reasons report.")
+
+        content_type = response.headers.get("Content-Type", "").lower()
+        if not content_type.startswith("application/octet-stream") and not response.text.startswith('"User","Device type"'):
+            raise Exception("Invalid response content type or unexpected response format.")
+
+        with open(filename, "wb") as f:
+            f.write(response.content)
+
+        return filename
+
+    @zcc_param_mapper
+    def list_devices(self, query_params: Optional[dict] = None) -> APIResult[List[Device]]:
         """
         Returns the list of devices enrolled in the Client Connector Portal.
 
@@ -272,7 +372,7 @@ class DevicesAPI(APIClient):
 
         return result, response, None
 
-    def get_device_cleanup_info(self) -> tuple:
+    def get_device_cleanup_info(self) -> APIResult[dict]:
         """
         Returns device cleanup sync information from the Client Connector Portal.
 
@@ -319,7 +419,7 @@ class DevicesAPI(APIClient):
 
         return result, response, None
 
-    def update_device_cleanup_info(self, **kwargs) -> tuple:
+    def update_device_cleanup_info(self, **kwargs) -> APIResult[dict]:
         """
         Set Device Cleaup Information
 
@@ -368,7 +468,7 @@ class DevicesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def get_device_details(self, query_params=None) -> tuple:
+    def get_device_details(self, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
        Lists device details of enrolled devices of your organization.
 
@@ -377,27 +477,25 @@ class DevicesAPI(APIClient):
                 ``[query_params.udid]`` {str, optional}: Filter by unique device identifier.
 
         Returns:
-            :obj:`list`: Returns device detail information in the Client Connector Portal.
+            :obj:`DeviceDetails`: Returns device detail information in the Client Connector Portal.
 
         Examples:
-            Prints all devices in the Client Connector Portal to the console:
+            Prints device details in the Client Connector Portal to the console:
 
             >>> details, _, err = client.zcc.devices.get_device_details()
             >>> if err:
             ...     print(f"Error listing device details: {err}")
             ...     return
-            ...  for device in details:
-            ...     print(device.as_dict())
+            ... print(details.as_dict())
 
-            Prints all devices in the Client Connector Portal to the console:
+            Prints device details in the Client Connector Portal to the console:
 
             >>> details, _, err = client.zcc.devices.get_device_details(
             ... query_params:{'username': 'jdoe'})
             >>> if err:
             ...     print(f"Error listing device details: {err}")
             ...     return
-            ...  for device in details:
-            ...     print(device.as_dict())
+            ... print(details.as_dict())
         """
         http_method = "get".upper()
         api_url = format_url(
@@ -417,20 +515,19 @@ class DevicesAPI(APIClient):
         if error:
             return (None, None, error)
 
-        response, error = self._request_executor.execute(request, DeviceDetails)
+        response, error = self._request_executor.execute(request)
         if error:
             return (None, response, error)
 
         try:
-            result = []
-            for item in response.get_results():
-                result.append(DeviceDetails(self.form_response_body(item)))
+            # Handle single object response directly since getDeviceDetails returns a single object
+            result = DeviceDetails(self.form_response_body(response.get_body()))
         except Exception as error:
             return (None, response, error)
         return (result, response, None)
 
     @zcc_param_mapper
-    def remove_devices(self, query_params=None, **kwargs) -> tuple:
+    def remove_devices(self, query_params: Optional[dict] = None, **kwargs) -> APIResult[dict]:
         """
         Remove of the devices from the Client Connector Portal.
 
@@ -499,7 +596,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zcc_param_mapper
-    def force_remove_devices(self, query_params=None, **kwargs) -> tuple:
+    def force_remove_devices(self, query_params: Optional[dict] = None, **kwargs) -> APIResult[dict]:
         """
         Force remove of the devices from the Client Connector Portal.
 
@@ -567,7 +664,7 @@ class DevicesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def remove_machine_tunnel(self, query_params=None, **kwargs) -> tuple:
+    def remove_machine_tunnel(self, query_params: Optional[dict] = None, **kwargs) -> APIResult[dict]:
         """
         Remove machine tunnel devices from the Client Connector Portal.
 
