@@ -14,20 +14,22 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.utils import format_url
 from zscaler.zcc.models.forwardingprofile import ForwardingProfile
+from zscaler.types import APIResult
 
 
 class ForwardingProfileAPI(APIClient):
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
         self._zcc_base_endpoint = "/zcc/papi/public/v1"
 
-    def list_by_company(self, query_params=None) -> tuple:
+    def list_by_company(self, query_params: Optional[dict] = None) -> APIResult[List[ForwardingProfile]]:
         """
         Returns the list of Forwarding Profiles By Company ID in the Client Connector Portal.
 
@@ -80,7 +82,7 @@ class ForwardingProfileAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def update_forwarding_profile(self, **kwargs) -> tuple:
+    def update_forwarding_profile(self, **kwargs) -> APIResult[dict]:
         """
        Updates a forwarding profile.
 
@@ -128,7 +130,7 @@ class ForwardingProfileAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def delete_forwarding_profile(self, profile_id: int) -> tuple:
+    def delete_forwarding_profile(self, profile_id: int) -> APIResult[dict]:
         """
         Deletes the specified Forwarding Profile.
 
