@@ -14,10 +14,12 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import List, Optional
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.utils import format_url
 from zscaler.zcc.models.webappservice import WebAppService
+from zscaler.types import APIResult
 
 
 class WebAppServiceAPI(APIClient):
@@ -27,7 +29,7 @@ class WebAppServiceAPI(APIClient):
         self._request_executor: RequestExecutor = request_executor
         self._zcc_base_endpoint = "/zcc/papi/public/v1"
 
-    def list_by_company(self, query_params=None) -> tuple:
+    def list_by_company(self, query_params: Optional[dict] = None) -> APIResult[List[WebAppService]]:
         """
         Returns the list of Fail Open Policy By Company in the Client Connector Portal.
 
