@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zdx.models.applications import ActiveApplications
@@ -23,17 +24,18 @@ from zscaler.zdx.models.applications import ApplicationMetrics
 from zscaler.zdx.models.application_users import ApplicationUserDetails
 from zscaler.zdx.models.application_users import ApplicationActiveUsers
 from zscaler.utils import format_url, zdx_params
+from zscaler.types import APIResult
 
 
 class AppsAPI(APIClient):
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
         self._zdx_base_endpoint = "/zdx/v1"
 
     @zdx_params
-    def list_apps(self, query_params=None) -> tuple:
+    def list_apps(self, query_params: Optional[dict] = None) -> APIResult[List[ActiveApplications]]:
         """
         Returns a list of all active applications configured within the ZDX tenant.
 
@@ -102,7 +104,7 @@ class AppsAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_app(self, app_id: str, query_params=None) -> tuple:
+    def get_app(self, app_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns information on the application's ZDX Score (for the previous 2 hours).
         Including most impacted locations, and the total number of users impacted.
@@ -164,7 +166,7 @@ class AppsAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_app_score(self, app_id: str, query_params=None) -> tuple:
+    def get_app_score(self, app_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns the ZDX score trend for the specified application configured within the ZDX tenant.
 
@@ -235,7 +237,7 @@ class AppsAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_app_metrics(self, app_id: str, query_params=None) -> tuple:
+    def get_app_metrics(self, app_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns the ZDX metrics for the specified application configured within the ZDX tenant.
 
@@ -314,7 +316,7 @@ class AppsAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def list_app_users(self, app_id: str, query_params=None) -> tuple:
+    def list_app_users(self, app_id: str, query_params: Optional[dict] = None) -> APIResult[List[ApplicationActiveUsers]]:
         """
         Returns a list of users and devices that were used to access the specified application configured within
         the ZDX tenant.
@@ -391,7 +393,7 @@ class AppsAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_app_user(self, app_id: str, user_id: str, query_params=None) -> tuple:
+    def get_app_user(self, app_id: str, user_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns information on the specified user and device that was used to access the specified application
         configured within the ZDX tenant.
