@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zdx.models.call_quality_metrics import CallQualityMetrics
@@ -30,17 +31,18 @@ from zscaler.zdx.models.devices import DeviceActiveApplications
 from zscaler.zdx.models.devices import DeviceHealthMetrics
 from zscaler.zdx.models.devices import DeviceEvents
 from zscaler.utils import format_url, zdx_params
+from zscaler.types import APIResult
 
 
 class DevicesAPI(APIClient):
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
         self._zdx_base_endpoint = "/zdx/v1"
 
     @zdx_params
-    def list_devices(self, query_params=None) -> tuple:
+    def list_devices(self, query_params: Optional[dict] = None) -> APIResult[List[Devices]]:
         """
         Returns a list of all active devices and its basic details.
         If the time range is not specified, the endpoint defaults to the previous 2 hours.
@@ -121,7 +123,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_device(self, device_id: str, query_params=None) -> tuple:
+    def get_device(self, device_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns a single device in ZDX.
 
@@ -185,7 +187,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_device_apps(self, device_id: str, query_params=None) -> tuple:
+    def get_device_apps(self, device_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns a list of all active applications for a device.
 
@@ -255,8 +257,8 @@ class DevicesAPI(APIClient):
         self,
         device_id: str,
         app_id: str,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[dict]:
         """
         Returns a single application for a device.
 
@@ -313,7 +315,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_web_probes(self, device_id: str, app_id: str, query_params=None) -> tuple:
+    def get_web_probes(self, device_id: str, app_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns a list of all active web probes for a specific application being used by a device.
 
@@ -382,7 +384,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_web_probe(self, device_id: str, app_id: str, probe_id: str, query_params=None) -> tuple:
+    def get_web_probe(self, device_id: str, app_id: str, probe_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns a single web probe for a specific application being used by a device.
 
@@ -451,7 +453,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def list_cloudpath_probes(self, device_id: str, app_id: str, query_params=None) -> tuple:
+    def list_cloudpath_probes(self, device_id: str, app_id: str, query_params: Optional[dict] = None) -> APIResult[List[DeviceAppCloudPathProbes]]:
         """
         Returns a list of all active cloudpath probes for a specific application being used by a device.
 
@@ -569,7 +571,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_cloudpath(self, device_id: str, app_id: str, probe_id: str, query_params=None) -> tuple:
+    def get_cloudpath(self, device_id: str, app_id: str, probe_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns a single cloudpath for a specific application being used by a device.
 
@@ -630,7 +632,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_call_quality_metrics(self, device_id: str, app_id: str, query_params=None) -> tuple:
+    def get_call_quality_metrics(self, device_id: str, app_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns a single call quality metrics for a specific application being used by a device.
 
@@ -685,7 +687,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_health_metrics(self, device_id: str, query_params=None) -> tuple:
+    def get_health_metrics(self, device_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns health metrics trend for a specific device.
 
@@ -742,7 +744,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_events(self, device_id: str, query_params=None) -> tuple:
+    def get_events(self, device_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns a list of all events for a specific device.
 
@@ -799,7 +801,7 @@ class DevicesAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def list_geolocations(self, query_params=None) -> tuple:
+    def list_geolocations(self, query_params: Optional[dict] = None) -> APIResult[List[DeviceActiveGeo]]:
         """
         Returns a list of all active geolocations configured within the ZDX tenant.
 
