@@ -14,22 +14,24 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zdx.models.software_inventory import SoftwareList
 from zscaler.zdx.models.software_inventory import DeviceSoftwareInventory
 from zscaler.utils import format_url, zdx_params
+from zscaler.types import APIResult
 
 
 class InventoryAPI(APIClient):
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
         self._zdx_base_endpoint = "/zdx/v1"
 
     @zdx_params
-    def list_softwares(self, query_params=None) -> tuple:
+    def list_softwares(self, query_params: Optional[dict] = None) -> APIResult[List[DeviceSoftwareInventory]]:
         """
         Returns a list of all software in ZDX.
 
@@ -100,7 +102,7 @@ class InventoryAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def list_software_keys(self, software_key: str, query_params=None) -> tuple:
+    def list_software_keys(self, software_key: str, query_params: Optional[dict] = None) -> APIResult[List[DeviceSoftwareInventory]]:
         """
         Returns a list of all users and devices for the given software name and version.
 
