@@ -14,22 +14,24 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zdx.models.users import ActiveUsers
 from zscaler.zdx.models.users import UserDeviceDetails
 from zscaler.utils import format_url, zdx_params
+from zscaler.types import APIResult
 
 
 class UsersAPI(APIClient):
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
         self._zdx_base_endpoint = "/zdx/v1"
 
     @zdx_params
-    def list_users(self, query_params=None) -> tuple:
+    def list_users(self, query_params: Optional[dict] = None) -> APIResult[List[ActiveUsers]]:
         """
         Returns a list of all active users configured within the ZDX tenant.
 
@@ -108,7 +110,7 @@ class UsersAPI(APIClient):
         return (result, response, None)
 
     @zdx_params
-    def get_user(self, user_id: str, query_params=None) -> tuple:
+    def get_user(self, user_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns information on the specified user configured within the ZDX tenant.
 
