@@ -14,11 +14,14 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import List, Optional
+
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zia.models.admin_roles import AdminRoles
 from zscaler.zia.models.admin_roles import PasswordExpiry
 from zscaler.utils import format_url
+from zscaler.types import APIResult
 
 
 class AdminRolesAPI(APIClient):
@@ -28,11 +31,11 @@ class AdminRolesAPI(APIClient):
 
     _zia_base_endpoint = "/zia/api/v1"
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
 
-    def list_roles(self, query_params=None) -> tuple:
+    def list_roles(self, query_params: Optional[dict] = None) -> APIResult[List[AdminRoles]]:
         """
         Return a list of the configured admin roles in ZIA.
 
@@ -103,7 +106,7 @@ class AdminRolesAPI(APIClient):
 
         return (results, response, None)
 
-    def get_role(self, role_id: int) -> tuple:
+    def get_role(self, role_id: int) -> APIResult[AdminRoles]:
         """
         Fetches a specific admin role by ID.
 
@@ -146,7 +149,7 @@ class AdminRolesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def add_role(self, **kwargs) -> tuple:
+    def add_role(self, **kwargs) -> APIResult[AdminRoles]:
         """
         Creates a new ZIA admin roles.
 
@@ -372,7 +375,7 @@ class AdminRolesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def update_role(self, role_id: int, **kwargs) -> tuple:
+    def update_role(self, role_id: int, **kwargs) -> APIResult[AdminRoles]:
         """
         Updates information for the specified ZIA admin role.
 
@@ -506,7 +509,7 @@ class AdminRolesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def delete_role(self, role_id: int) -> tuple:
+    def delete_role(self, role_id: int) -> APIResult[None]:
         """
         Deletes the specified admin roles.
 
@@ -542,7 +545,7 @@ class AdminRolesAPI(APIClient):
             return (None, response, error)
         return (None, response, None)
 
-    def get_password_expiry_settings(self) -> tuple:
+    def get_password_expiry_settings(self) -> APIResult[PasswordExpiry]:
         """
         Retrieves the password expiration information for all the admins
 
@@ -588,7 +591,7 @@ class AdminRolesAPI(APIClient):
         except Exception as ex:
             return (None, response, ex)
 
-    def update_password_expiry_settings(self, **kwargs) -> tuple:
+    def update_password_expiry_settings(self, **kwargs) -> APIResult[PasswordExpiry]:
         """
         Updates the password expiration information for all the admins.
 
