@@ -14,24 +14,26 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.request_executor import RequestExecutor
 from zscaler.utils import format_url, transform_common_id_fields, reformat_params
 from zscaler.api_client import APIClient
 from zscaler.zia.models.casb_malware_rules import CasbMalwareRules
+from zscaler.types import APIResult
 
 
 class CasbMalwareRulesAPI(APIClient):
 
     _zia_base_endpoint = "/zia/api/v1"
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
 
     def list_rules(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[CasbMalwareRules]]:
         """
         Returns a list of all Casb Malware Rules for the specified rule type.
 
@@ -97,7 +99,7 @@ class CasbMalwareRulesAPI(APIClient):
         self,
         rule_id: int,
         rule_type: str,
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Returns information for the specified casb malware rule under the specified rule type.
 
@@ -155,7 +157,7 @@ class CasbMalwareRulesAPI(APIClient):
 
     def list_all_rules(
         self,
-    ) -> tuple:
+    ) -> APIResult[List[CasbMalwareRules]]:
         """
         Returns a list of all Casb Malware Rules.
 
@@ -206,7 +208,7 @@ class CasbMalwareRulesAPI(APIClient):
 
         return (result, response, None)
 
-    def add_rule(self, **kwargs) -> tuple:
+    def add_rule(self, **kwargs) -> APIResult[dict]:
         """
         Adds a new cloud app control rule.
 
@@ -286,7 +288,7 @@ class CasbMalwareRulesAPI(APIClient):
 
         return (result, response, None)
 
-    def update_rule(self, rule_id: str, **kwargs) -> tuple:
+    def update_rule(self, rule_id: str, **kwargs) -> APIResult[dict]:
         """
         Updates an existing casb malware rule.
 
@@ -367,7 +369,7 @@ class CasbMalwareRulesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def delete_rule(self, rule_type: str, rule_id: int) -> tuple:
+    def delete_rule(self, rule_type: str, rule_id: int) -> APIResult[dict]:
         """
         Deletes the specified Casb Malware Rules.
 
