@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import List, Optional
 from zscaler.request_executor import RequestExecutor
 from zscaler.api_client import APIClient
 from zscaler.zia.models.cloud_firewall_destination_groups import IPDestinationGroups
@@ -24,17 +25,20 @@ from zscaler.zia.models.cloud_firewall_nw_service_groups import NetworkServiceGr
 from zscaler.zia.models.cloud_firewall_nw_service import NetworkServices
 from zscaler.zia.models.cloud_firewall_time_windows import TimeWindows
 from zscaler.utils import format_url, transform_common_id_fields, reformat_params
+from zscaler.types import APIResult
 
 
 class FirewallResourcesAPI(APIClient):
 
     _zia_base_endpoint = "/zia/api/v1"
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
 
-    def list_ip_destination_groups(self, exclude_type: str = None, query_params=None) -> tuple:
+    def list_ip_destination_groups(
+        self, exclude_type: str = None, query_params: Optional[dict] = None
+    ) -> APIResult[List[IPDestinationGroups]]:
         """
         Returns a list of IP Destination Groups.
 
@@ -116,7 +120,9 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def list_ipv6_destination_groups(self, exclude_type: str = None, query_params=None) -> tuple:
+    def list_ipv6_destination_groups(
+        self, exclude_type: str = None, query_params: Optional[dict] = None
+    ) -> APIResult[List[IPDestinationGroups]]:
         """
         Lists IPv6 Destination Groups name and ID  all IPv6 Source Groups.
         `Note`: User-defined groups for IPv6 addresses are currently not supported,
@@ -200,7 +206,11 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def list_ip_destination_groups_lite(self, exclude_type: str = None, query_params=None) -> tuple:
+    def list_ip_destination_groups_lite(
+        self,
+        exclude_type: str = None,
+        query_params: Optional[dict] = None
+    ) -> APIResult[List[IPDestinationGroups]]:
         """
         Lists IP Destination Groups name and ID  all IP Destination Groups.
         This endpoint retrieves only IPv4 destination address groups.
@@ -290,7 +300,11 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def list_ipv6_destination_groups_lite(self, exclude_type: str = None, query_params=None) -> tuple:
+    def list_ipv6_destination_groups_lite(
+        self,
+        exclude_type: str = None,
+        query_params: Optional[dict] = None
+    ) -> APIResult[List[IPDestinationGroups]]:
         """
         Lists IPv6 Destination Groups name and ID  all IPv6 Source Groups.
         `Note`: User-defined groups for IPv6 addresses are currently not supported,
@@ -381,7 +395,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def get_ip_destination_group(self, group_id: int) -> tuple:
+    def get_ip_destination_group(self, group_id: int) -> APIResult[dict]:
         """
         Returns information on the specified IP Destination Group.
 
@@ -426,7 +440,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def add_ip_destination_group(self, **kwargs) -> tuple:
+    def add_ip_destination_group(self, **kwargs) -> APIResult[dict]:
         """
         Adds a new IP Destination Group.
 
@@ -514,11 +528,23 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def update_ip_destination_group(self, group_id: str, **kwargs) -> tuple:
+    def update_ip_destination_group(
+        self,
+        group_id: str,
+        query_params: Optional[dict] = None,
+        **kwargs
+    ) -> APIResult[dict]:
         """
         Updates the specified IP Destination Group.
 
         Args:
+            query_params (dict):
+                Map of query parameters for the request.
+
+                ``[query_params.override]`` (bool): Indicates whether the IPs must be overridden.
+                    When set to false, the IPs are appended
+                    Else the existing IPs are overridden. The default value is true.
+
             group_id (str): The unique ID of the IP Destination Group.
             **kwargs: Optional keyword args.
 
@@ -602,7 +628,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def delete_ip_destination_group(self, group_id: int) -> tuple:
+    def delete_ip_destination_group(self, group_id: int) -> APIResult[dict]:
         """
         Deletes the specified IP Destination Group.
 
@@ -640,8 +666,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_ip_source_groups(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[IPSourceGroup]]:
         """
         List IP Source Groups in your organization.
 
@@ -708,8 +734,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_ipv6_source_groups(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[IPSourceGroup]]:
         """
         List IPv6 Source Groups in your organization.
         `Note`: User-defined groups for IPv6 addresses are currently not supported,
@@ -778,8 +804,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_ip_source_groups_lite(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[IPSourceGroup]]:
         """
         Lists IP Source Groups name and ID  all IP Source Groups.
         This endpoint retrieves only IPv4 source address groups.
@@ -853,8 +879,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_ipv6_source_groups_lite(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[IPSourceGroup]]:
         """
         Lists IPv6 Source Groups name and ID all IPv6 Source Groups.
         `Note`: User-defined groups for IPv6 addresses are currently not supported,
@@ -930,7 +956,7 @@ class FirewallResourcesAPI(APIClient):
     def get_ip_source_group(
         self,
         group_id: int,
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Returns information for the specified IP Source Group.
 
@@ -972,7 +998,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def add_ip_source_group(self, **kwargs) -> tuple:
+    def add_ip_source_group(self, **kwargs) -> APIResult[dict]:
         """
         Adds a new IP Source Group.
 
@@ -1026,7 +1052,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def update_ip_source_group(self, group_id: int, **kwargs) -> tuple:
+    def update_ip_source_group(self, group_id: int, **kwargs) -> APIResult[dict]:
         """
         Update an IP Source Group.
 
@@ -1089,7 +1115,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def delete_ip_source_group(self, group_id: int) -> tuple:
+    def delete_ip_source_group(self, group_id: int) -> APIResult[dict]:
         """
         Deletes an IP Source Group.
 
@@ -1127,8 +1153,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_network_app_groups(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[NetworkApplicationGroups]]:
         """
         List Network Application Groups in your organization.
 
@@ -1196,7 +1222,7 @@ class FirewallResourcesAPI(APIClient):
     def get_network_app_group(
         self,
         group_id: int,
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Returns information for the specified Network Application Group.
 
@@ -1241,7 +1267,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def add_network_app_group(self, **kwargs) -> tuple:
+    def add_network_app_group(self, **kwargs) -> APIResult[dict]:
         """
         Adds a new Network Application Group.
 
@@ -1296,7 +1322,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def update_network_app_group(self, group_id: int, **kwargs) -> tuple:
+    def update_network_app_group(self, group_id: int, **kwargs) -> APIResult[dict]:
         """
         Update an Network Application Group.
 
@@ -1356,7 +1382,7 @@ class FirewallResourcesAPI(APIClient):
     def delete_network_app_group(
         self,
         group_id: int,
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Deletes the specified Network Application Group.
 
@@ -1394,8 +1420,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_network_apps(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[NetworkApplications]]:
         """
         Lists Network Applications in your organization with pagination.
         A subset of Network Applications can be returned that match a supported
@@ -1467,7 +1493,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def get_network_app(self, app_id: int) -> tuple:
+    def get_network_app(self, app_id: int) -> APIResult[dict]:
         """
         Returns information for the specified Network Application.
 
@@ -1510,8 +1536,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_network_svc_groups(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[NetworkServiceGroups]]:
         """
         Lists network service groups in your organization with pagination.
         A subset of network service groups can be returned that match a supported
@@ -1581,8 +1607,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_network_svc_groups_lite(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[NetworkServiceGroups]]:
         """
         Lists Network Service Groups name and ID  all network service groups.
         If the `search` parameter is provided, the function filters the rules client-side.
@@ -1654,7 +1680,7 @@ class FirewallResourcesAPI(APIClient):
 
         return (results, response, None)
 
-    def get_network_svc_group(self, group_id: int) -> tuple:
+    def get_network_svc_group(self, group_id: int) -> APIResult[dict]:
         """
         Returns information for the specified Network Service Group.
 
@@ -1697,7 +1723,7 @@ class FirewallResourcesAPI(APIClient):
 
         return (result, response, None)
 
-    def add_network_svc_group(self, **kwargs) -> tuple:
+    def add_network_svc_group(self, **kwargs) -> APIResult[dict]:
         """
         Adds a new Network Service Group.
 
@@ -1753,7 +1779,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def update_network_svc_group(self, group_id: int, **kwargs) -> tuple:
+    def update_network_svc_group(self, group_id: int, **kwargs) -> APIResult[dict]:
         """
         Update a Network Service Group.
 
@@ -1812,7 +1838,7 @@ class FirewallResourcesAPI(APIClient):
     def delete_network_svc_group(
         self,
         group_id: int,
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Deletes the specified Network Service Group.
 
@@ -1849,7 +1875,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (None, response, None)
 
-    def list_network_services(self, query_params=None) -> tuple:
+    def list_network_services(self, query_params: Optional[dict] = None) -> APIResult[List[NetworkServices]]:
         """
         Lists network services in your organization with pagination.
         A subset of network services  can be returned that match a supported
@@ -1922,8 +1948,8 @@ class FirewallResourcesAPI(APIClient):
 
     def list_network_services_lite(
         self,
-        query_params=None,
-    ) -> tuple:
+        query_params: Optional[dict] = None,
+    ) -> APIResult[List[NetworkServices]]:
         """
         Lists network services name and ID all network services.
         A subset of network service groups can be returned that match a supported
@@ -1999,7 +2025,7 @@ class FirewallResourcesAPI(APIClient):
 
         return (results, response, None)
 
-    def get_network_service(self, service_id: int) -> tuple:
+    def get_network_service(self, service_id: int) -> APIResult[dict]:
         """
         Returns information for the specified Network Service.
 
@@ -2044,7 +2070,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def add_network_service(self, ports: list = None, **kwargs) -> tuple:
+    def add_network_service(self, ports: list = None, **kwargs) -> APIResult[dict]:
         """
         Adds a new Network Service
 
@@ -2124,7 +2150,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def update_network_service(self, service_id: str, ports: list = None, **kwargs) -> tuple:
+    def update_network_service(self, service_id: str, ports: list = None, **kwargs) -> APIResult[dict]:
         """
         Updates the specified Network Service.
 
@@ -2204,7 +2230,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def delete_network_service(self, service_id: int) -> tuple:
+    def delete_network_service(self, service_id: int) -> APIResult[dict]:
         """
         Deletes the specified Network Service.
 
@@ -2241,7 +2267,7 @@ class FirewallResourcesAPI(APIClient):
             return (None, response, error)
         return (None, response, None)
 
-    def list_time_windows(self) -> tuple:
+    def list_time_windows(self) -> APIResult[List[TimeWindows]]:
         """
         Returns a list of time intervals used by the Firewall policy or the URL Filtering policy.
 
@@ -2282,7 +2308,7 @@ class FirewallResourcesAPI(APIClient):
 
         return (result, response, None)
 
-    def list_time_windows_lite(self) -> tuple:
+    def list_time_windows_lite(self) -> APIResult[List[TimeWindows]]:
         """
         Returns name and ID dictionary of time intervals used by the Firewall policy or the URL Filtering policy.
 
