@@ -14,10 +14,12 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zia.models.malware_protection_settings import MalwareSettings
 from zscaler.utils import format_url
+from zscaler.types import APIResult
 
 
 class MalwareProtectionPolicyAPI(APIClient):
@@ -27,11 +29,11 @@ class MalwareProtectionPolicyAPI(APIClient):
 
     _zia_base_endpoint = "/zia/api/v1"
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
 
-    def get_atp_malware_policy(self) -> tuple:
+    def get_atp_malware_policy(self) -> APIResult[dict]:
         """
         Retrieves the Malware Protection Policy configuration.
 
@@ -82,7 +84,11 @@ class MalwareProtectionPolicyAPI(APIClient):
         except Exception as ex:
             return (None, response, ex)
 
-    def update_atp_malware_policy(self, block_unscannable_files: bool, block_password_protected_archive_files: bool) -> tuple:
+    def update_atp_malware_policy(
+        self,
+        block_unscannable_files: bool,
+        block_password_protected_archive_files: bool
+    ) -> APIResult[dict]:
         """
         Updates the Malware Protection Policy configuration.
 
@@ -146,7 +152,7 @@ class MalwareProtectionPolicyAPI(APIClient):
         except Exception as ex:
             return (None, response, ex)
 
-    def get_atp_malware_inspection(self) -> tuple:
+    def get_atp_malware_inspection(self) -> APIResult[dict]:
         """
         Retrieves the traffic inspection configurations of Malware Protection policy
 
@@ -198,7 +204,7 @@ class MalwareProtectionPolicyAPI(APIClient):
         except Exception as ex:
             return (None, response, ex)
 
-    def update_atp_malware_inspection(self, inspect_inbound: bool, inspect_outbound: bool) -> tuple:
+    def update_atp_malware_inspection(self, inspect_inbound: bool, inspect_outbound: bool) -> APIResult[dict]:
         """
         Updates the traffic inspection configurations of Malware Protection policy.
 
@@ -263,7 +269,7 @@ class MalwareProtectionPolicyAPI(APIClient):
         except Exception as ex:
             return (None, response, ex)
 
-    def get_atp_malware_protocols(self) -> tuple:
+    def get_atp_malware_protocols(self) -> APIResult[dict]:
         """
         Retrieves the traffic protocols configurations of Malware Protection policy
 
@@ -320,7 +326,12 @@ class MalwareProtectionPolicyAPI(APIClient):
         except Exception as ex:
             return (None, response, ex)
 
-    def update_atp_malware_protocols(self, inspect_http: bool, inspect_ftp_over_http: bool, inspect_ftp: bool) -> tuple:
+    def update_atp_malware_protocols(
+        self,
+        inspect_http: bool,
+        inspect_ftp_over_http: bool,
+        inspect_ftp: bool
+    ) -> APIResult[dict]:
         """
         Updates the traffic protocols configurations of Malware Protection policy.
 
@@ -394,7 +405,7 @@ class MalwareProtectionPolicyAPI(APIClient):
         except Exception as ex:
             return (None, response, ex)
 
-    def get_malware_settings(self) -> tuple:
+    def get_malware_settings(self) -> APIResult[dict]:
         """
         Retrieves the malware protection policy configuration details
 
@@ -438,7 +449,7 @@ class MalwareProtectionPolicyAPI(APIClient):
         except Exception as ex:
             return (None, response, ex)
 
-    def update_malware_settings(self, settings: MalwareSettings) -> tuple:
+    def update_malware_settings(self, settings: MalwareSettings) -> APIResult[dict]:
         """
         Updates the malware protection policy configuration details
 
