@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.oneapi_object import ZscalerObject
 from zscaler.oneapi_collection import ZscalerCollection
 
@@ -36,7 +37,7 @@ class DLPWebRules(ZscalerObject):
     A class representing a DLP Web Rule object.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
         if config:
             self.id = config["id"] if "id" in config else None
@@ -75,8 +76,11 @@ class DLPWebRules(ZscalerObject):
             self.user_risk_score_levels = ZscalerCollection.form_list(
                 config["userRiskScoreLevels"] if "userRiskScoreLevels" in config else [], str
             )
+            self.dlp_content_locations_scopes = ZscalerCollection.form_list(
+                config["dlpContentLocationsScopes"] if "dlpContentLocationsScopes" in config else [], str
+            )
             self.url_categories = ZscalerCollection.form_list(
-                config["urlCategories"] if "urlCategories" in config else [], common_reference.ResourceReference
+                config["urlCategories"] if "urlCategories" in config else [], urlcategory.URLCategory
             )
 
             self.locations = ZscalerCollection.form_list(
@@ -176,9 +180,11 @@ class DLPWebRules(ZscalerObject):
             self.auditor = None
             self.notification_template = None
             self.icap_server = None
-            self.external_auditor_email = None  # New attribute
+            self.external_auditor_email = None
+            self.dlp_content_locations_scopes = []
+            self.dlp_engines = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -229,7 +235,9 @@ class DLPWebRules(ZscalerObject):
             "auditor": self.auditor.request_format() if self.auditor else None,
             "notificationTemplate": self.notification_template.request_format() if self.notification_template else None,
             "icapServer": self.icap_server.request_format() if self.icap_server else None,
-            "externalAuditorEmail": self.external_auditor_email,  # New Attribute
+            "externalAuditorEmail": self.external_auditor_email,
+            "dlpContentLocationsScopes": self.dlp_content_locations_scopes,
+            "dlpEngines": [engine.request_format() for engine in (self.dlp_engines or [])],
         }
         parent_req_format.update(current_obj_format)
         return parent_req_format
