@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.oneapi_object import ZscalerObject
 from zscaler.oneapi_collection import ZscalerCollection
 
@@ -25,7 +26,7 @@ class LocationManagement(ZscalerObject):
     A class representing a Location object.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
         # print("🚨 Raw config passed into LocationManagement:")
         # import pprint
@@ -39,6 +40,7 @@ class LocationManagement(ZscalerObject):
             self.up_bandwidth = config["upBandwidth"] if "upBandwidth" in config else None
             self.dn_bandwidth = config["dnBandwidth"] if "dnBandwidth" in config else None
             self.country = config["country"] if "country" in config else None
+            self.state = config["state"] if "state" in config else None
             self.language = config["language"] if "language" in config else None
             self.tz = config["tz"] if "tz" in config else None
             self.geo_override = config["geoOverride"] if "geoOverride" in config else False
@@ -66,11 +68,18 @@ class LocationManagement(ZscalerObject):
                 or False  # ← fallback
             )
 
+            self.surrogate_ip_enforced_for_known_browsers = (
+                config.get("surrogate_ip_enforced_for_known_browsers")  # ← used by the converted keys
+                or config.get("surrogateIpEnforcedForKnownBrowsers")  # ← if not snake_cased
+                or config.get("surrogateIPEnforcedForKnownBrowsers")  # ← raw from the API
+                or False  # ← fallback
+            )
+
             self.cookies_and_proxy = config["cookiesAndProxy"] if "cookiesAndProxy" in config else None
             self.idle_time_in_minutes = config["idleTimeInMinutes"] if "idleTimeInMinutes" in config else None
             self.display_time_unit = config["displayTimeUnit"] if "displayTimeUnit" in config else None
-            self.surrogate_ip_enforced_for_known_browsers = (
-                config["surrogateIPEnforcedForKnownBrowsers"] if "surrogateIPEnforcedForKnownBrowsers" in config else False
+            self.surrogate_refresh_time_unit = (
+                config["surrogateRefreshTimeUnit"] if "surrogateRefreshTimeUnit" in config else None
             )
             self.surrogate_refresh_time_in_minutes = (
                 config["surrogateRefreshTimeInMinutes"] if "surrogateRefreshTimeInMinutes" in config else None
@@ -106,7 +115,15 @@ class LocationManagement(ZscalerObject):
             self.basic_auth_enabled = config["basicAuthEnabled"] if "basicAuthEnabled" in config else False
 
             self.digest_auth_enabled = config["digestAuthEnabled"] if "digestAuthEnabled" in config else False
-
+            self.ports = ZscalerCollection.form_list(
+                config["ports"] if "ports" in config else [], str
+            )
+            self.sub_loc_scope_values = ZscalerCollection.form_list(
+                config["subLocScopeValues"] if "subLocScopeValues" in config else [], str
+            )
+            self.sub_loc_acc_ids = ZscalerCollection.form_list(config["subLocAccIds"] if "subLocAccIds" in config else [], str)
+            self.sub_loc_scope_enabled = config["subLocScopeEnabled"] if "subLocScopeEnabled" in config else None
+            self.sub_loc_scope = config["subLocScope"] if "subLocScope" in config else None
             # Handling nested lists and collections
             self.static_location_groups = ZscalerCollection.form_list(
                 config["staticLocationGroups"] if "staticLocationGroups" in config else [], common.CommonIDName
@@ -161,6 +178,7 @@ class LocationManagement(ZscalerObject):
             self.up_bandwidth = None
             self.dn_bandwidth = None
             self.country = None
+            self.state = None
             self.language = None
             self.tz = None
             self.geo_override = False
@@ -199,12 +217,17 @@ class LocationManagement(ZscalerObject):
             self.extranet = None
             self.extranet_ip_pool = None
             self.extranet_dns = None
+            self.ports = []
             self.static_location_groups = []
             self.dynamic_location_groups = []
             self.vpn_credentials = []
             self.ip_addresses = []
+            self.sub_loc_scope_enabled = False
+            self.sub_loc_scope = None
+            self.sub_loc_scope_values = []
+            self.sub_loc_acc_ids = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -217,6 +240,7 @@ class LocationManagement(ZscalerObject):
             "upBandwidth": self.up_bandwidth,
             "dnBandwidth": self.dn_bandwidth,
             "country": self.country,
+            "state": self.state,
             "language": self.language,
             "tz": self.tz,
             "geoOverride": self.geo_override,
@@ -234,6 +258,7 @@ class LocationManagement(ZscalerObject):
             "displayTimeUnit": self.display_time_unit,
             "surrogateIPEnforcedForKnownBrowsers": self.surrogate_ip_enforced_for_known_browsers,
             "surrogateRefreshTimeInMinutes": self.surrogate_refresh_time_in_minutes,
+            "surrogateRefreshTimeUnit": self.surrogate_refresh_time_unit,
             "kerberosAuth": self.kerberos_auth,
             "basicAuthEnabled": self.basic_auth_enabled,
             "digestAuthEnabled": self.digest_auth_enabled,
@@ -255,10 +280,12 @@ class LocationManagement(ZscalerObject):
             "ipAddresses": self.ip_addresses,
             "ipv6Enabled": self.ipv6_enabled,
             "extranet": self.extranet,
+            "ports": self.ports,
             "extranetIpPool": self.extranet_ip_pool,
             "extranetDns": self.extranet_dns,
             "defaultExtranetTsPool": self.default_extranet_ts_pool,
             "defaultExtranetDns": self.default_extranet_dns,
+
             "staticLocationGroups": [static.request_format() for static in (self.static_location_groups or [])],
             "dynamiclocationGroups": [dyn.request_format() for dyn in (self.dynamic_location_groups or [])],
             "vpnCredentials": [vpn.request_format() for vpn in (self.vpn_credentials or [])],
@@ -272,7 +299,7 @@ class VPNCredentials(ZscalerObject):
     A class representing a VPN Credentials object.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
 
         if config:
@@ -290,7 +317,7 @@ class VPNCredentials(ZscalerObject):
             self.comments = None
             self.location = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -311,7 +338,7 @@ class RegionInfo(ZscalerObject):
     A class for RegionInfo objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the RegionInfo model based on API response.
 
@@ -353,7 +380,7 @@ class RegionInfo(ZscalerObject):
             self.postal_code = None
             self.continent_code = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
