@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.oneapi_object import ZscalerObject
 from zscaler.oneapi_collection import ZscalerCollection
 from zscaler.zia.models import common
@@ -24,7 +25,7 @@ class DomainProfiles(ZscalerObject):
     A class for DomainProfiles objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the DomainProfiles model based on API response.
 
@@ -60,7 +61,7 @@ class DomainProfiles(ZscalerObject):
             self.custom_domains = []
             self.predefined_email_domains = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -83,7 +84,7 @@ class QuarantineTombstoneTemplate(ZscalerObject):
     A class for QuarantineTombstoneTemplate objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the QuarantineTombstoneTemplate model based on API response.
 
@@ -105,7 +106,7 @@ class QuarantineTombstoneTemplate(ZscalerObject):
             self.name = None
             self.description = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -124,7 +125,7 @@ class CasbEmailLabel(ZscalerObject):
     A class for CasbEmailLabel objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the CasbEmailLabel model based on API response.
 
@@ -151,7 +152,7 @@ class CasbEmailLabel(ZscalerObject):
             self.label_color = None
             self.label_deleted = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -172,7 +173,7 @@ class CasbTenant(ZscalerObject):
     A class for CasbTenant objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the CasbTenant model based on API response.
 
@@ -230,7 +231,7 @@ class CasbTenant(ZscalerObject):
             self.re_auth = None
             self.features_supported = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -251,3 +252,99 @@ class CasbTenant(ZscalerObject):
         }
         parent_req_format.update(current_obj_format)
         return parent_req_format
+
+
+class SaaSScanInfo(ZscalerObject):
+    """
+    A class for SaaSScanInfo objects.
+    """
+
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
+        """
+        Initialize the SaaSScanInfo model based on API response.
+
+        Args:
+            config (dict): A dictionary representing the configuration.
+        """
+        super().__init__(config)
+
+        if config:
+            self.tenant_name = config["tenantName"] \
+                if "tenantName" in config else None
+            self.tenant_id = config["tenantId"] \
+                if "tenantId" in config else None
+            self.saas_application = config["saasApplication"] \
+                if "saasApplication" in config else None
+            self.scan_action = config["scanAction"] \
+                if "scanAction" in config else None
+
+            if "scanInfo" in config:
+                if isinstance(config["scanInfo"], ScanInfo):
+                    self.scan_info = config["scanInfo"]
+                elif config["scanInfo"] is not None:
+                    self.scan_info = ScanInfo(config["scanInfo"])
+                else:
+                    self.scan_info = None
+            else:
+                self.scan_info = None
+        else:
+            self.tenant_name = None
+            self.tenant_id = None
+            self.saas_application = None
+            self.scan_info = None
+            self.scan_action = None
+
+    def request_format(self) -> Dict[str, Any]:
+        """
+        Return the object as a dictionary in the format expected for API requests.
+        """
+        parent_req_format = super().request_format()
+        current_obj_format = {
+            "tenantName": self.tenant_name,
+            "tenantId": self.tenant_id,
+            "saasApplication": self.saas_application,
+            "scanInfo": self.scan_info,
+            "scanAction": self.scan_action
+        }
+        parent_req_format.update(current_obj_format)
+        return parent_req_format
+
+
+class ScanInfo(ZscalerObject):
+    """
+    A class for ScanInfo objects.
+    """
+
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
+        """
+        Initialize the ScanInfo model based on API response.
+
+        Args:
+            config (dict): A dictionary representing the configuration.
+        """
+        super().__init__(config)
+
+        if config:
+            self.cur_scan_start_time = config["cur_scan_start_time"] \
+                if "cur_scan_start_time" in config else None
+            self.prev_scan_end_time = config["prev_scan_end_time"] \
+                if "prev_scan_end_time" in config else None
+            self.scan_reset_num = config["scan_reset_num"] \
+                if "scan_reset_num" in config else None
+        else:
+            self.cur_scan_start_time = None
+            self.prev_scan_end_time = None
+            self.scan_reset_num = None
+
+    def request_format(self) -> Dict[str, Any]:
+        """
+        Return the object as a dictionary in the format expected for API requests.
+        """
+        parent_req_format = super().request_format()
+        current_obj_format = {
+            "cur_scan_start_time": self.cur_scan_start_time,
+            "prev_scan_end_time": self.prev_scan_end_time,
+            "scan_reset_num": self.scan_reset_num
+        }
+        parent_req_format.update(current_obj_format)
+        return parent_req_format
