@@ -14,10 +14,12 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zia.models.risk_profiles import RiskProfiles
 from zscaler.utils import format_url
+from zscaler.types import APIResult
 
 
 class RiskProfilesAPI(APIClient):
@@ -27,11 +29,11 @@ class RiskProfilesAPI(APIClient):
 
     _zia_base_endpoint = "/zia/api/v1"
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
 
-    def list_risk_profiles(self, query_params=None) -> tuple:
+    def list_risk_profiles(self, query_params: Optional[dict] = None) -> APIResult[List[RiskProfiles]]:
         """
         Retrieves the cloud application risk profile
 
@@ -86,7 +88,7 @@ class RiskProfilesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def list_risk_profiles_lite(self) -> tuple:
+    def list_risk_profiles_lite(self) -> APIResult[List[RiskProfiles]]:
         """
         Retrieves the cloud application risk profile lite
 
@@ -135,7 +137,7 @@ class RiskProfilesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def get_risk_profile(self, profile_id: int) -> tuple:
+    def get_risk_profile(self, profile_id: int) -> APIResult[dict]:
         """
         Fetches a specific risk profile by ID.
 
@@ -181,7 +183,7 @@ class RiskProfilesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def add_risk_profile(self, **kwargs) -> tuple:
+    def add_risk_profile(self, **kwargs) -> APIResult[dict]:
         """
         Creates a new ZIA Risk Profile.
 
@@ -332,7 +334,7 @@ class RiskProfilesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def update_risk_profile(self, profile_id: int, **kwargs) -> tuple:
+    def update_risk_profile(self, profile_id: int, **kwargs) -> APIResult[dict]:
         """
         Updates information for the specified ZIA Risk Profile.
 
@@ -412,7 +414,7 @@ class RiskProfilesAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def delete_risk_profile(self, profile_id: int) -> tuple:
+    def delete_risk_profile(self, profile_id: int) -> APIResult[dict]:
         """
         Deletes the specified Risk Profile.
 
