@@ -14,13 +14,16 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zia.models.saas_security_api import DomainProfiles
 from zscaler.zia.models.saas_security_api import QuarantineTombstoneTemplate
 from zscaler.zia.models.saas_security_api import CasbEmailLabel
 from zscaler.zia.models.saas_security_api import CasbTenant
+from zscaler.zia.models.saas_security_api import SaaSScanInfo
 from zscaler.utils import format_url
+from zscaler.types import APIResult
 
 
 class SaaSSecurityAPI(APIClient):
@@ -30,11 +33,11 @@ class SaaSSecurityAPI(APIClient):
 
     _zia_base_endpoint = "/zia/api/v1"
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
 
-    def list_domain_profiles_lite(self) -> tuple:
+    def list_domain_profiles_lite(self) -> APIResult[List[DomainProfiles]]:
         """
         Retrieves the domain profile summary
 
@@ -88,7 +91,7 @@ class SaaSSecurityAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def list_quarantine_tombstone_lite(self) -> tuple:
+    def list_quarantine_tombstone_lite(self) -> APIResult[List[QuarantineTombstoneTemplate]]:
         """
         Retrieves the templates for the tombstone file created when a file is quarantined
 
@@ -142,7 +145,7 @@ class SaaSSecurityAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def list_casb_email_label_lite(self) -> tuple:
+    def list_casb_email_label_lite(self) -> APIResult[List[CasbEmailLabel]]:
         """
         Retrieves the email labels generated for the SaaS Security API policies in a user's email account
 
@@ -196,7 +199,7 @@ class SaaSSecurityAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def list_casb_tenant_lite(self, query_params=None) -> tuple:
+    def list_casb_tenant_lite(self, query_params: Optional[dict] = None) -> APIResult[List[CasbTenant]]:
         """
         Retrieves the email labels generated for the SaaS Security API policies in a user's email account
 
@@ -277,3 +280,62 @@ class SaaSSecurityAPI(APIClient):
         except Exception as error:
             return (None, response, error)
         return (result, response, None)
+
+    def list_saas_scan_info(self, query_params: Optional[dict] = None) -> APIResult[List[SaaSScanInfo]]:
+        """
+        Retrieves the SaaS Security Scan Configuration information.
+
+        Args:
+            query_params (dict):
+                Map of query parameters for the request.
+
+                ``[query_params.page]`` (int): Specifies the page offset.
+
+                ``[query_params.page_size]`` (int): Specifies the page size.
+                    The default size is 500.
+
+        Returns:
+            tuple:
+                List SaaS Security Scan Configuration information (SaaSScanInfo, Response, error).
+
+        Examples:
+            List all SaaS Security Scan Configuration information:
+
+            >>> scan_info_list, _, err = client.zia.saas_security_api.list_saas_scan_info()
+            >>> if err:
+            ...     print(f"Error listing scan information: {err}")
+            ...     return
+            ... print(f"Total scan information found: {len(scan_info_list)}")
+            ... for scan_info in scan_info_list:
+            ...     print(scan_info.as_dict())
+        """
+        http_method = "get".upper()
+        api_url = format_url(
+            f"""
+            {self._zia_base_endpoint}
+            /casbTenant/scanInfo
+        """
+        )
+
+        query_params = query_params or {}
+
+        body = {}
+        headers = {}
+
+        request, error = self._request_executor.create_request(http_method, api_url, body, headers, params=query_params)
+
+        if error:
+            return (None, None, error)
+
+        response, error = self._request_executor.execute(request)
+
+        if error:
+            return (None, response, error)
+
+        try:
+            result = []
+            for item in response.get_results():
+                result.append(SaaSScanInfo(self.form_response_body(item)))
+        except Exception as error:
+            return (None, response, error)
+        return (result, response, None)
