@@ -14,10 +14,12 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 import mimetypes
 import time
 from zscaler.request_executor import RequestExecutor
 from zscaler.utils import format_url
+from zscaler.types import APIResult
 
 
 class CloudSandboxAPI:
@@ -28,10 +30,10 @@ class CloudSandboxAPI:
     _sandbox_base_endpoint = "/zscsb"
     _zia_base_endpoint = "/zia/api/v1"
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         self._request_executor: RequestExecutor = request_executor
 
-    def submit_file(self, file_path: str, force: bool = False) -> tuple:
+    def submit_file(self, file_path: str, force: bool = False) -> APIResult[dict]:
         """
         Submits a file to the ZIA Advanced Cloud Sandbox for analysis.
 
@@ -95,7 +97,7 @@ class CloudSandboxAPI:
 
         return (result, response, None)
 
-    def submit_file_for_inspection(self, file_path: str) -> tuple:
+    def submit_file_for_inspection(self, file_path: str) -> APIResult[dict]:
         """
         Submits a file for inspection.
 
@@ -159,7 +161,7 @@ class CloudSandboxAPI:
 
         return (result, response, None)
 
-    def get_quota(self) -> tuple:
+    def get_quota(self) -> APIResult[dict]:
         """
         Returns the Cloud Sandbox API quota information for the organisation.
 
@@ -194,7 +196,7 @@ class CloudSandboxAPI:
 
         return (result, response, None)
 
-    def get_report(self, md5_hash: str, report_details: str = "summary") -> tuple:
+    def get_report(self, md5_hash: str, report_details: str = "summary") -> APIResult[dict]:
         """
         Returns the Cloud Sandbox Report for the provided hash.
 
@@ -237,7 +239,7 @@ class CloudSandboxAPI:
 
         return (result, response, None)
 
-    def get_behavioral_analysis(self) -> tuple:
+    def get_behavioral_analysis(self) -> APIResult[dict]:
         """
         Returns the custom list of MD5 file hashes that are blocked by Sandbox.
 
@@ -272,7 +274,7 @@ class CloudSandboxAPI:
 
         return (result, response, None)
 
-    def get_file_hash_count(self) -> tuple:
+    def get_file_hash_count(self) -> APIResult[dict]:
         """
         Retrieves the Cloud Sandbox used and unused quota for blocking MD5 file hashes.
 
@@ -312,7 +314,7 @@ class CloudSandboxAPI:
 
         return (result, response, None)
 
-    def add_hash_to_custom_list(self, file_hashes_to_be_blocked: list) -> tuple:
+    def add_hash_to_custom_list(self, file_hashes_to_be_blocked: list) -> APIResult[dict]:
         """
         Updates the custom list of MD5 file hashes that are blocked by Sandbox.
 
