@@ -14,10 +14,12 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zia.models.shadow_it_report import CloudapplicationsAndTags
 from zscaler.utils import format_url, convert_keys
+from zscaler.types import APIResult
 
 
 class ShadowITAPI(APIClient):
@@ -27,7 +29,7 @@ class ShadowITAPI(APIClient):
 
     _zia_base_endpoint = "/zia/api/v1"
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
 
@@ -43,7 +45,7 @@ class ShadowITAPI(APIClient):
         """
         return [{"id": str(id)} for id in id_list]
 
-    def list_apps(self, query_params=None) -> tuple:
+    def list_apps(self, query_params: Optional[dict] = None) -> APIResult[List[CloudapplicationsAndTags]]:
         """
         Gets the list of predefined and custom cloud applications
 
@@ -102,7 +104,7 @@ class ShadowITAPI(APIClient):
 
         return (result, response, None)
 
-    def list_custom_tags(self) -> tuple:
+    def list_custom_tags(self) -> APIResult[List[CloudapplicationsAndTags]]:
         """
         List all custom tags by name and id.
 
@@ -150,7 +152,7 @@ class ShadowITAPI(APIClient):
 
         return (result, response, None)
 
-    def bulk_update(self, sanction_state: str, **kwargs) -> tuple:
+    def bulk_update(self, sanction_state: str, **kwargs) -> APIResult[dict]:
         """
         Updates application status and tag information for predefined or custom cloud applications based on the
         IDs specified.
@@ -245,7 +247,7 @@ class ShadowITAPI(APIClient):
         result = self.form_response_body(body) if body else {}
         return (result, response, None)
 
-    def export_shadow_it_report(self, duration: str = "LAST_1_DAYS", **kwargs) -> tuple:
+    def export_shadow_it_report(self, duration: str = "LAST_1_DAYS", **kwargs) -> APIResult[dict]:
         """
         Export the Shadow IT Report (in CSV format) for the cloud applications recognized by Zscaler
         based on their usage in your organisation.
