@@ -14,10 +14,12 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zpa.models.idp import IDPController
 from zscaler.utils import format_url
+from zscaler.types import APIResult
 
 
 class IDPControllerAPI(APIClient):
@@ -32,7 +34,7 @@ class IDPControllerAPI(APIClient):
         self._zpa_base_endpoint = f"/zpa/mgmtconfig/v1/admin/customers/{customer_id}"
         self._zpa_base_endpoint_v2 = f"/zpa/mgmtconfig/v2/admin/customers/{customer_id}"
 
-    def list_idps(self, query_params=None) -> tuple:
+    def list_idps(self, query_params: Optional[dict] = None) -> APIResult[List[IDPController]]:
         """
         Enumerates identity provider in your organization with pagination.
         A subset of identity provider can be returned that match a supported
@@ -97,7 +99,7 @@ class IDPControllerAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def get_idp(self, idp_id: str) -> tuple:
+    def get_idp(self, idp_id: str) -> APIResult[dict]:
         """
         Returns information on the specified identity provider (IdP).
 
