@@ -14,8 +14,10 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.oneapi_object import ZscalerObject
 from zscaler.oneapi_collection import ZscalerCollection
+from zscaler.zpa.models import application_segment as application_segment
 
 
 class CommonIDName(ZscalerObject):
@@ -24,7 +26,7 @@ class CommonIDName(ZscalerObject):
     Handles common block attributes shared across multiple resources
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the CommonIDName model based on API response.
 
@@ -41,7 +43,7 @@ class CommonIDName(ZscalerObject):
             self.name = None
             self.enabled = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Returns the object as a dictionary in the format expected for API requests.
         """
@@ -61,7 +63,7 @@ class CommonNameReason(ZscalerObject):
     Handles common block attributes shared across multiple resources
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the CommonNameReason model based on API response.
 
@@ -76,7 +78,7 @@ class CommonNameReason(ZscalerObject):
             self.id = None
             self.reason = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Returns the object as a dictionary in the format expected for API requests.
         """
@@ -95,7 +97,7 @@ class ExtranetDTO(ZscalerObject):
     Handles common block attributes shared across multiple resources
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the ExtranetDTO model based on API response.
 
@@ -128,7 +130,7 @@ class ExtranetDTO(ZscalerObject):
             self.zia_er_id = None
             self.location_dto = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Returns the object as a dictionary in the format expected for API requests.
         """
@@ -152,7 +154,7 @@ class LocationGroupDTO(ZscalerObject):
     Handles common block attributes shared across multiple resources
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the LocationGroupDTO model based on API response.
 
@@ -173,7 +175,7 @@ class LocationGroupDTO(ZscalerObject):
             self.name = None
             self.zia_locations = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Returns the object as a dictionary in the format expected for API requests.
         """
@@ -192,7 +194,7 @@ class InspectionControlException(ZscalerObject):
     A class for InspectionControlException objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the InspectionControlException model based on API response.
 
@@ -216,7 +218,7 @@ class InspectionControlException(ZscalerObject):
             self.variables = None
             self.version = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -236,7 +238,7 @@ class Domains(ZscalerObject):
     A class for Domains objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the Domains model based on API response.
 
@@ -252,7 +254,7 @@ class Domains(ZscalerObject):
             self.match_type = None
             self.var_value = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -270,7 +272,7 @@ class Paths(ZscalerObject):
     A class for Paths objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the Paths model based on API response.
 
@@ -286,7 +288,7 @@ class Paths(ZscalerObject):
             self.match_type = None
             self.var_value = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -304,7 +306,7 @@ class Variables(ZscalerObject):
     A class for Variables objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the Variables model based on API response.
 
@@ -320,7 +322,7 @@ class Variables(ZscalerObject):
             self.match_type = None
             self.var_value = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -339,7 +341,7 @@ class PrivilegedCapabilitiesResource(ZscalerObject):
     Handles common block attributes shared across multiple resources
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the CommonIDName model based on API response.
 
@@ -355,7 +357,7 @@ class PrivilegedCapabilitiesResource(ZscalerObject):
             self.capabilities = None
             self.microtenant_id = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Returns the object as a dictionary in the format expected for API requests.
         """
@@ -373,7 +375,7 @@ class CommonFilterSearch(ZscalerObject):
     A class for CommonFilterSearch objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the CommonFilterSearch model based on API response.
 
@@ -396,7 +398,7 @@ class CommonFilterSearch(ZscalerObject):
             self.page_by = None
             self.sort_by = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -411,7 +413,7 @@ class FilterBy(ZscalerObject):
     A class for FilterBy objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the FilterBy model based on API response.
 
@@ -432,7 +434,7 @@ class FilterBy(ZscalerObject):
             self.operator = None
             self.values = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -452,7 +454,7 @@ class PageBy(ZscalerObject):
     A class for PageBy objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the PageBy model based on API response.
 
@@ -472,7 +474,7 @@ class PageBy(ZscalerObject):
             self.valid_page = None
             self.valid_page_size = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -492,7 +494,7 @@ class SortBy(ZscalerObject):
     A class for SortBy objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         """
         Initialize the SortBy model based on API response.
 
@@ -508,7 +510,7 @@ class SortBy(ZscalerObject):
             self.sort_name = None
             self.sort_order = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Return the object as a dictionary in the format expected for API requests.
         """
@@ -519,3 +521,54 @@ class SortBy(ZscalerObject):
         }
         parent_req_format.update(current_obj_format)
         return parent_req_format
+
+
+class DesktopPolicyMappingsDTO(ZscalerObject):
+    """
+    A class for DesktopPolicyMappingsDTO objects.
+    Handles common block attributes shared across multiple resources
+    """
+
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
+        """
+        Initialize the DesktopPolicyMappingsDTO model based on API response.
+
+        Args:
+            config (dict): A dictionary representing the response.
+        """
+        super().__init__(config)
+        if config:
+            self.id = config["id"] if "id" in config else None
+            self.modified_time = config["modifiedTime"] if "modifiedTime" in config else None
+            self.creation_time = config["creationTime"] if "creationTime" in config else None
+            self.modified_by = config["modifiedBy"] if "modifiedBy" in config else None
+            self.image_id = config["imageId"] if "imageId" in config else None
+            self.image_name = config["imageName"] if "imageName" in config else None
+            self.app_segments = ZscalerCollection.form_list(
+                config["appSegments"] if "appSegments" in config else [], application_segment.ApplicationSegments
+            )
+        else:
+            self.id = None
+            self.modified_time = None
+            self.creation_time = None
+            self.modified_by = None
+            self.image_id = None
+            self.image_name = None
+            self.app_segments = []
+
+    def request_format(self) -> Dict[str, Any]:
+        """
+        Returns the object as a dictionary in the format expected for API requests.
+        """
+        parent_req_format = super().request_format()
+        current_obj_format = {
+            "id": self.id,
+            "modifiedTime": self.modified_time,
+            "creationTime": self.creation_time,
+            "modifiedBy": self.modified_by,
+            "imageId": self.image_id,
+            "imageName": self.image_name,
+            "appSegments": [segment.as_dict() for segment in self.app_segments],
+        }
+        parent_req_format.update(current_obj_format)
+        return parent_req_format
