@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.oneapi_object import ZscalerObject
 from zscaler.oneapi_collection import ZscalerCollection
 from zscaler.zpa.models import app_connector_groups as app_connector_groups
@@ -28,7 +29,7 @@ class PolicySetControllerV1(ZscalerObject):
     A class representing a Policy Set Controller.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
 
         if config:
@@ -49,6 +50,8 @@ class PolicySetControllerV1(ZscalerObject):
             self.reauth_idle_timeout = config["reauthIdleTimeout"] if "reauthIdleTimeout" in config else None
             self.reauth_timeout = config["reauthTimeout"] if "reauthTimeout" in config else None
             self.custom_msg = config["customMsg"] if "customMsg" in config else None
+            self.device_posture_failure_notification_enabled = config["devicePostureFailureNotificationEnabled"] \
+                if "devicePostureFailureNotificationEnabled" in config else None
             self.disabled = config["disabled"] if "disabled" in config else None
             self.extranet_enabled = config["extranetEnabled"] if "extranetEnabled" in config else False
             self.microtenant_id = config["microtenantId"] if "microtenantId" in config else None
@@ -78,6 +81,10 @@ class PolicySetControllerV1(ZscalerObject):
                 config["serviceEdgeGroups"] if "serviceEdgeGroups" in config else [], service_edge_groups.ServiceEdgeGroup
             )
 
+            self.desktop_policy_mappings = ZscalerCollection.form_list(
+                config["desktopPolicyMappings"] if "desktopPolicyMappings" in config else [], common.DesktopPolicyMappingsDTO
+            )
+
             if "privilegedCapabilities" in config:
                 if isinstance(config["privilegedCapabilities"], common.PrivilegedCapabilitiesResource):
                     self.privileged_capabilities = config["privilegedCapabilities"]
@@ -167,8 +174,10 @@ class PolicySetControllerV1(ZscalerObject):
             self.reauth_timeout = None
             self.read_only = None
             self.zscaler_managed = None
+            self.device_posture_failure_notification_enabled = None
+            self.desktop_policy_mappings = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         parent_req_format = super().request_format()
         current_obj_format = {
             "id": self.id,
@@ -208,6 +217,8 @@ class PolicySetControllerV1(ZscalerObject):
             "appConnectorGroups": [group.request_format() for group in self.app_connector_groups],
             "appServerGroups": [group.request_format() for group in self.app_server_groups],
             "serviceEdgeGroups": [group.request_format() for group in self.service_edge_groups],
+            "devicePostureFailureNotificationEnabled": self.device_posture_failure_notification_enabled,
+            "desktopPolicyMappings": [mapping.request_format() for mapping in self.desktop_policy_mappings],
         }
         parent_req_format.update(current_obj_format)
         return parent_req_format
@@ -215,7 +226,7 @@ class PolicySetControllerV1(ZscalerObject):
 
 # The Condition class used within PolicySetController (kept inline with how operands are structured)
 class Condition(ZscalerObject):
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
 
         if config:
@@ -238,7 +249,7 @@ class Condition(ZscalerObject):
             self.negated = False
             self.operands = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         parent_req_format = super().request_format()
         current_obj_format = {
             "id": self.id,
@@ -254,7 +265,7 @@ class Condition(ZscalerObject):
 
 
 class Operand(ZscalerObject):
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
 
         if config:
@@ -281,7 +292,7 @@ class Operand(ZscalerObject):
             self.idp_id = None
             self.idp_name = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         parent_req_format = super().request_format()
         current_obj_format = {
             "id": self.id,
