@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.oneapi_object import ZscalerObject
 from zscaler.oneapi_collection import ZscalerCollection
 from zscaler.zpa.models import app_connector_groups as app_connector_groups
@@ -27,7 +28,7 @@ class PolicySetControllerV2(ZscalerObject):
     A class representing a Policy Set Controller V2.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
 
         if config:
@@ -48,6 +49,8 @@ class PolicySetControllerV2(ZscalerObject):
             self.reauth_idle_timeout = config["reauthIdleTimeout"] if "reauthIdleTimeout" in config else None
             self.reauth_timeout = config["reauthTimeout"] if "reauthTimeout" in config else None
             self.custom_msg = config["customMsg"] if "customMsg" in config else None
+            self.device_posture_failure_notification_enabled = config["devicePostureFailureNotificationEnabled"] \
+                if "devicePostureFailureNotificationEnabled" in config else None
             self.disabled = config["disabled"] if "disabled" in config else None
             self.extranet_enabled = config["extranetEnabled"] if "extranetEnabled" in config else False
             self.microtenant_id = config["microtenantId"] if "microtenantId" in config else None
@@ -81,6 +84,10 @@ class PolicySetControllerV2(ZscalerObject):
                 config["serviceEdgeGroups"] if "serviceEdgeGroups" in config else [], service_edge_groups.ServiceEdgeGroup
             )
 
+            self.desktop_policy_mappings = ZscalerCollection.form_list(
+                config["desktopPolicyMappings"] if "desktopPolicyMappings" in config else [], common.DesktopPolicyMappingsDTO
+            )
+
             if "privilegedCapabilities" in config:
                 if isinstance(config["privilegedCapabilities"], common.PrivilegedCapabilitiesResource):
                     self.privileged_capabilities = config["privilegedCapabilities"]
@@ -172,8 +179,10 @@ class PolicySetControllerV2(ZscalerObject):
             self.reauth_timeout = None
             self.read_only = None
             self.zscaler_managed = None
+            self.device_posture_failure_notification_enabled = None
+            self.desktop_policy_mappings = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         parent_req_format = super().request_format()
         current_obj_format = {
             "id": self.id,
@@ -214,13 +223,15 @@ class PolicySetControllerV2(ZscalerObject):
             "appConnectorGroups": [group.request_format() for group in self.app_connector_groups],
             "appServerGroups": [group.request_format() for group in self.app_server_groups],
             "serviceEdgeGroups": [group.request_format() for group in self.service_edge_groups],
+            "devicePostureFailureNotificationEnabled": self.device_posture_failure_notification_enabled,
+            "desktopPolicyMappings": [mapping.request_format() for mapping in self.desktop_policy_mappings],
         }
         parent_req_format.update(current_obj_format)
         return parent_req_format
 
 
 class Condition(ZscalerObject):
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
 
         if config:
@@ -237,7 +248,7 @@ class Condition(ZscalerObject):
             self.operator = None
             self.operands = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         parent_req_format = super().request_format()
         current_obj_format = {"operator": self.operator, "operands": [operand.request_format() for operand in self.operands]}
         parent_req_format.update(current_obj_format)
@@ -245,7 +256,7 @@ class Condition(ZscalerObject):
 
 
 class Operand(ZscalerObject):
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
 
         if config:
@@ -262,7 +273,7 @@ class Operand(ZscalerObject):
             self.values = []
             self.entry_values = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         parent_req_format = super().request_format()
         current_obj_format = {"objectType": self.object_type, "values": self.values, "entryValues": self.entry_values}
         parent_req_format.update(current_obj_format)
@@ -270,7 +281,7 @@ class Operand(ZscalerObject):
 
 
 class Credential(ZscalerObject):
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
 
         if config:
@@ -282,8 +293,11 @@ class Credential(ZscalerObject):
             self.id = None
             self.name = None
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         parent_req_format = super().request_format()
-        current_obj_format = {"id": self.id, "name": self.name}
+        current_obj_format = {
+            "id": self.id,
+            "name": self.name
+        }
         parent_req_format.update(current_obj_format)
         return parent_req_format
