@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.oneapi_object import ZscalerObject
 from zscaler.oneapi_collection import ZscalerCollection
 from zscaler.zpa.models import application_segment as application_segment
@@ -24,7 +25,7 @@ class SegmentGroup(ZscalerObject):
     A class for Segment Group objects.
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config: Optional[Dict[str, Any]] = None) -> None:
         super().__init__(config)
         if config:
             self.id = config["id"] if "id" in config else None
@@ -56,7 +57,7 @@ class SegmentGroup(ZscalerObject):
             self.skip_detailed_app_info = None
             self.applications = []
 
-    def request_format(self):
+    def request_format(self) -> Dict[str, Any]:
         """
         Formats the Segment Group data into a dictionary suitable for API requests.
         """
