@@ -14,6 +14,7 @@ ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 """
 
+from typing import Dict, List, Optional, Any, Union
 from zscaler.api_client import APIClient
 from zscaler.request_executor import RequestExecutor
 from zscaler.zwa.models.change_history import ChangeHistory
@@ -24,16 +25,17 @@ from zscaler.zwa.models.incident_search import IncidentSearch
 from zscaler.zwa.models.incident_group_search import IncidentGroupSearch
 from zscaler.zwa.models.incident_trigger import IncidentTrigger
 from zscaler.utils import format_url
+from zscaler.types import APIResult
 
 
 class DLPIncidentsAPI(APIClient):
 
-    def __init__(self, request_executor):
+    def __init__(self, request_executor: "RequestExecutor") -> None:
         super().__init__()
         self._request_executor: RequestExecutor = request_executor
         self._zwa_base_endpoint = "/zwa/dlp/v1"
 
-    def get_incident_transactions(self, transaction_id: str, query_params=None) -> tuple:
+    def get_incident_transactions(self, transaction_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns information DLP incident details based on the incident ID.
 
@@ -88,7 +90,7 @@ class DLPIncidentsAPI(APIClient):
 
         return (result, response, None)
 
-    def get_incident_details(self, incident_id: str, query_params=None) -> tuple:
+    def get_incident_details(self, incident_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns information DLP incident details based on the incident ID.
 
@@ -143,7 +145,7 @@ class DLPIncidentsAPI(APIClient):
 
         return (result, response, None)
 
-    def change_history(self, incident_id: str, query_params=None) -> tuple:
+    def change_history(self, incident_id: str, query_params: Optional[dict] = None) -> APIResult[dict]:
         """
         Returns details of updates made to an incident based on the given ID and timeline.
 
@@ -195,7 +197,7 @@ class DLPIncidentsAPI(APIClient):
     def get_incident_triggers(
         self,
         incident_id: str,
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Returns information DLP incident details based on the incident ID.
 
@@ -245,7 +247,7 @@ class DLPIncidentsAPI(APIClient):
     def get_generated_tickets(
         self,
         incident_id: str,
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Returns details of of the ticket generated for the incident.
         For example, ticket type, ticket ID, ticket status, etc.
@@ -300,7 +302,7 @@ class DLPIncidentsAPI(APIClient):
     def get_incident_evidence(
         self,
         incident_id: str,
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Gets the evidence URL of the incident.
         The evidence link can be used to view and download the XML file with the actual
@@ -347,7 +349,13 @@ class DLPIncidentsAPI(APIClient):
 
         return (result, response, None)
 
-    def dlp_incident_search(self, query_params=None, fields=None, time_range=None, **kwargs) -> tuple:
+    def dlp_incident_search(
+        self,
+        query_params: Optional[dict] = None,
+        fields=None,
+        time_range=None,
+        **kwargs
+    ) -> APIResult[dict]:
         """
         Filters DLP incidents based on the given time range and field values.
 
@@ -456,7 +464,7 @@ class DLPIncidentsAPI(APIClient):
             return (None, response, error)
         return (result, response, None)
 
-    def incident_group_search(self, incident_id: str, incident_group_ids: list = None) -> tuple:
+    def incident_group_search(self, incident_id: str, incident_group_ids: list = None) -> APIResult[dict]:
         """
         Filters a list of DLP incident groups to which the specified incident ID belongs.
 
@@ -498,7 +506,7 @@ class DLPIncidentsAPI(APIClient):
 
         return (result, response, None)
 
-    def assign_labels(self, incident_id: str, labels: list = None) -> tuple:
+    def assign_labels(self, incident_id: str, labels: list = None) -> APIResult[dict]:
         """
         Assigns labels (name-value pairs) to a DLP incident.
 
@@ -546,7 +554,7 @@ class DLPIncidentsAPI(APIClient):
 
         return (result, response, None)
 
-    def incident_notes(self, incident_id: str, notes: str = None) -> tuple:
+    def incident_notes(self, incident_id: str, notes: str = None) -> APIResult[dict]:
         """
         Adds notes to a DLP incident.
 
@@ -596,7 +604,7 @@ class DLPIncidentsAPI(APIClient):
 
     def incident_close(
         self, incident_id: str, resolution_label: dict = None, resolution_code: str = None, notes: str = None
-    ) -> tuple:
+    ) -> APIResult[dict]:
         """
         Updates the status of the incident to resolved and closes the incident with a resolution label and a resolution code.
 
